from ... pyaz_utils import call_az
from . import managed, self_hosted


def list(resource_group, workspace_name):
    '''
    List integration runtimes.
    '''
    return call_az("az synapse integration-runtime list", locals())


def show(name, resource_group, workspace_name, if_none_match=None):
    '''
    Get an integration runtime.
    '''
    return call_az("az synapse integration-runtime show", locals())


def create(name, resource_group, type, workspace_name, compute_type=None, core_count=None, description=None, if_match=None, location=None, no_wait=None, time_to_live=None):
    '''
    Create an integration runtime.
    '''
    return call_az("az synapse integration-runtime create", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete an integration runtime.
    '''
    return call_az("az synapse integration-runtime delete", locals())


def update(auto_update, name, resource_group, update_delay_offset, workspace_name):
    '''
    Update an integration runtime.
    '''
    return call_az("az synapse integration-runtime update", locals())


def start(name, resource_group, workspace_name, no_wait=None):
    '''
    start an SSIS integration runtime.
    '''
    return call_az("az synapse integration-runtime start", locals())


def stop(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    stop an SSIS integration runtime.
    '''
    return call_az("az synapse integration-runtime stop", locals())


def upgrade(name, resource_group, workspace_name):
    '''
    Upgrade self-hosted integration runtime.
    '''
    return call_az("az synapse integration-runtime upgrade", locals())


def list_auth_key(name, resource_group, workspace_name):
    '''
    Get keys for a self-hosted integration runtime.
    '''
    return call_az("az synapse integration-runtime list-auth-key", locals())


def regenerate_auth_key(name, resource_group, workspace_name, key_name=None):
    '''
    Regenerate self-hosted integration runtime key.
    '''
    return call_az("az synapse integration-runtime regenerate-auth-key", locals())


def get_monitoring_data(name, resource_group, workspace_name):
    '''
    Get metric data for a self-hosted integration runtime.
    '''
    return call_az("az synapse integration-runtime get-monitoring-data", locals())


def sync_credentials(name, resource_group, workspace_name):
    '''
    Synchronize credentials among integration runtime nodes.
    '''
    return call_az("az synapse integration-runtime sync-credentials", locals())


def get_connection_info(name, resource_group, workspace_name):
    '''
    Get the integration runtime connection infomation.
    '''
    return call_az("az synapse integration-runtime get-connection-info", locals())


def get_status(name, resource_group, workspace_name):
    '''
    Gets detailed status information for an integration runtime.
    '''
    return call_az("az synapse integration-runtime get-status", locals())


def wait(name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, if_none_match=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a integration runtime is met.
    '''
    return call_az("az synapse integration-runtime wait", locals())




from ... pyaz_utils import call_az
from . import certificate


def list(cluster_name, resource_group):
    '''
    List applications of a given cluster.
    '''
    return call_az("az sf application list", locals())


def delete(cluster_name, name, resource_group):
    '''
    Delete an application.
    '''
    return call_az("az sf application delete", locals())


def show(cluster_name, name, resource_group):
    '''
    Show the properties of an application on an Azure Service Fabric cluster.
    '''
    return call_az("az sf application show", locals())


def create(cluster_name, name, resource_group, type_name, version, max_nodes=None, min_nodes=None, package_url=None, parameters=None):
    '''
    Create a new application on an Azure Service Fabric cluster.
    '''
    return call_az("az sf application create", locals())


def update(cluster_name, name, resource_group, failure_action=None, force_restart=None, hc_retry_timeout=None, hc_stable_duration=None, hc_wait_duration=None, max_nodes=None, max_porcent_unhealthy_apps=None, max_porcent_unhealthy_partitions=None, max_porcent_unhealthy_replicas=None, max_porcent_unhealthy_services=None, min_nodes=None, parameters=None, service_type_health_policy_map=None, ud_timeout=None, upgrade_replica_set_check_timeout=None, upgrade_timeout=None, version=None, warning_as_error=None):
    '''
    Update a Azure Service Fabric application. This allows updating the application parameters and/or upgrade the application type version which will trigger an application upgrade.
    '''
    return call_az("az sf application update", locals())




from ..... pyaz_utils import call_az

def show(name, partner_namespace_name, resource_group):
    '''
    Get the details of an event channel under a partner namespace.
    '''
    return call_az("az eventgrid partner namespace event-channel show", locals())


def delete(name, partner_namespace_name, resource_group, yes=None):
    '''
    Delete a partner namespace.
    '''
    return call_az("az eventgrid partner namespace event-channel delete", locals())


def list(partner_namespace_name, resource_group, odata_query=None):
    '''
    List available partner event-channels.
    '''
    return call_az("az eventgrid partner namespace event-channel list", locals())


def create(destination_resource_group_name, destination_subscription_id, destination_topic_name, name, partner_namespace_name, resource_group, source, activation_expiration_date=None, partner_topic_description=None, publisher_filter=None):
    '''
    Create an event channel under a partner namespace.
    '''
    return call_az("az eventgrid partner namespace event-channel create", locals())




from .. pyaz_utils import call_az
from . import collection, database, identity, keys, locations, network_rule, private_endpoint_connection, private_link_resource, restorable_database_account, table


def show(name, resource_group):
    '''
    Get the details of an Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb show", locals())


def list_keys(name, resource_group):
    '''
    List the access keys for a Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb list-keys", locals())


def list_read_only_keys(name, resource_group):
    '''
    List the read-only access keys for a Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb list-read-only-keys", locals())


def list_connection_strings(name, resource_group):
    '''
    List the connection strings for a Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb list-connection-strings", locals())


def regenerate_key(key_kind, name, resource_group):
    '''
    Regenerate an access key for a Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb regenerate-key", locals())


def check_name_exists(name):
    '''
    Checks if an Azure Cosmos DB account name exists.
    '''
    return call_az("az cosmosdb check-name-exists", locals())


def delete(name, resource_group, yes=None):
    '''
    Deletes an Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb delete", locals())


def failover_priority_change(failover_policies, name, resource_group):
    '''
    Changes the failover priority for the Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb failover-priority-change", locals())


def create(name, resource_group, analytical_storage_schema_type=None, assign_identity=None, backup_interval=None, backup_policy_type=None, backup_redundancy=None, backup_retention=None, capabilities=None, databases_to_restore=None, default_consistency_level=None, default_identity=None, disable_key_based_metadata_write_access=None, enable_analytical_storage=None, enable_automatic_failover=None, enable_free_tier=None, enable_multiple_write_locations=None, enable_public_network=None, enable_virtual_network=None, ip_range_filter=None, is_restore_request=None, key_uri=None, kind=None, locations=None, max_interval=None, max_staleness_prefix=None, network_acl_bypass=None, network_acl_bypass_resource_ids=None, restore_source=None, restore_timestamp=None, server_version=None, tags=None, virtual_network_rules=None):
    '''
    Creates a new Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb create", locals())


def update(name, resource_group, analytical_storage_schema_type=None, backup_interval=None, backup_policy_type=None, backup_redundancy=None, backup_retention=None, capabilities=None, default_consistency_level=None, default_identity=None, disable_key_based_metadata_write_access=None, enable_analytical_storage=None, enable_automatic_failover=None, enable_multiple_write_locations=None, enable_public_network=None, enable_virtual_network=None, ip_range_filter=None, locations=None, max_interval=None, max_staleness_prefix=None, network_acl_bypass=None, network_acl_bypass_resource_ids=None, server_version=None, tags=None, virtual_network_rules=None):
    '''
    Update an Azure Cosmos DB database account.
    '''
    return call_az("az cosmosdb update", locals())


def list(resource_group=None):
    '''
    List Azure Cosmos DB database accounts.
    '''
    return call_az("az cosmosdb list", locals())


def restore(account_name, location, resource_group, restore_timestamp, target_database_account_name, databases_to_restore=None):
    '''
    Create a new Azure Cosmos DB database account by restoring from an existing database account.
    '''
    return call_az("az cosmosdb restore", locals())




from ... pyaz_utils import call_az

def create(file, name, workspace_name, no_wait=None):
    '''
    Create a trigger.
    '''
    return call_az("az synapse trigger create", locals())


def set(file, name, workspace_name, no_wait=None):
    '''
    Update an exist trigger.
    '''
    return call_az("az synapse trigger set", locals())


def update(file, name, workspace_name, no_wait=None):
    '''
    Update an exist trigger.
    '''
    return call_az("az synapse trigger update", locals())


def list(workspace_name):
    '''
    List triggers.
    '''
    return call_az("az synapse trigger list", locals())


def show(name, workspace_name):
    '''
    Get a trigger.
    '''
    return call_az("az synapse trigger show", locals())


def delete(name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a trigger.
    '''
    return call_az("az synapse trigger delete", locals())


def subscribe_to_event(name, workspace_name, no_wait=None):
    '''
    Subscribe event trigger to events.
    '''
    return call_az("az synapse trigger subscribe-to-event", locals())


def get_event_subscription_status(name, workspace_name):
    '''
    Get a trigger's event subscription status.
    '''
    return call_az("az synapse trigger get-event-subscription-status", locals())


def unsubscribe_from_event(name, workspace_name, no_wait=None):
    '''
    Unsubscribe event trigger from events.
    '''
    return call_az("az synapse trigger unsubscribe-from-event", locals())


def start(name, workspace_name, no_wait=None):
    '''
    Starts a trigger.
    '''
    return call_az("az synapse trigger start", locals())


def stop(name, workspace_name, no_wait=None):
    '''
    Stops a trigger.
    '''
    return call_az("az synapse trigger stop", locals())


def wait(name, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a trigger is met.
    '''
    return call_az("az synapse trigger wait", locals())




from .... pyaz_utils import call_az

def list(instance_id, location, restore_location, restore_timestamp):
    '''
    List all the databases and its containers that can be restored in the given account at the given timesamp and region.
    '''
    return call_az("az cosmosdb sql restorable-resource list", locals())




from .... pyaz_utils import call_az

def create(outbound_rule_fqdn, resource_group, server):
    '''
    Create a new outbound firewall rule.
    '''
    return call_az("az sql server outbound-firewall-rule create", locals())


def delete(outbound_rule_fqdn, resource_group, server):
    '''
    Delete the outbound firewall rule.
    '''
    return call_az("az sql server outbound-firewall-rule delete", locals())


def show(outbound_rule_fqdn, resource_group, server):
    '''
    Show the details for an outbound firewall rule.
    '''
    return call_az("az sql server outbound-firewall-rule show", locals())


def list(resource_group, server):
    '''
    List a server's outbound firewall rules.
    '''
    return call_az("az sql server outbound-firewall-rule list", locals())




from ... pyaz_utils import call_az
from . import autostorage_keys, keys


def list(resource_group=None):
    '''
    List the Batch accounts associated with a subscription or resource group.
    '''
    return call_az("az batch account list", locals())


def show(name=None, resource_group=None):
    '''
    Get a specified Batch account or the currently set account.
    '''
    return call_az("az batch account show", locals())


def create(location, name, resource_group, encryption_key_identifier=None, encryption_key_source=None, identity_type=None, keyvault=None, no_wait=None, public_network_access=None, storage_account=None, tags=None):
    '''
    Create a Batch account with the specified parameters.
    '''
    return call_az("az batch account create", locals())


def set(name, resource_group, encryption_key_identifier=None, encryption_key_source=None, identity_type=None, storage_account=None, tags=None):
    '''
    Update properties for a Batch account.
    '''
    return call_az("az batch account set", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    return call_az("az batch account delete", locals())


def login(name, resource_group, shared_key_auth=None, show=None):
    '''
    Log in to a Batch account through Azure Active Directory or Shared Key authentication.
    '''
    return call_az("az batch account login", locals())


def outbound_endpoints(name, resource_group):
    '''
    List an account's outbound network dependencies.
    '''
    return call_az("az batch account outbound-endpoints", locals())




from .... pyaz_utils import call_az

def add(account_name, name, resource_group, base64_key=None, expiration=None, identifier=None):
    '''
    Add an AkamaiAccessControl to an existing streaming endpoint.
    '''
    return call_az("az ams streaming-endpoint akamai add", locals())


def remove(account_name, identifier, name, resource_group):
    '''
    Remove an AkamaiAccessControl from an existing streaming endpoint.
    '''
    return call_az("az ams streaming-endpoint akamai remove", locals())




from .... pyaz_utils import call_az
from . import keys


def create(name, namespace_name, relay_name, resource_group, rights=None):
    '''
    Create Authorization Rule for the given Relay Service WCF Relay.
    '''
    return call_az("az relay wcfrelay authorization-rule create", locals())


def show(name, namespace_name, relay_name, resource_group):
    '''
    show properties of Authorization Rule for the given Relay Service WCF Relay.
    '''
    return call_az("az relay wcfrelay authorization-rule show", locals())


def list(namespace_name, relay_name, resource_group):
    '''
    List of Authorization Rule by Relay Service WCF Relay.
    '''
    return call_az("az relay wcfrelay authorization-rule list", locals())


def delete(name, namespace_name, relay_name, resource_group):
    '''
    Delete the Authorization Rule of Relay Service WCF Relay
    '''
    return call_az("az relay wcfrelay authorization-rule delete", locals())


def update(name, namespace_name, relay_name, resource_group, rights, add=None, force_string=None, remove=None, set=None):
    '''
    Update Authorization Rule for the given Relay Service WCF Relay.
    '''
    return call_az("az relay wcfrelay authorization-rule update", locals())




from ... pyaz_utils import call_az

def create(lock_type, name, notes=None, resource_group=None):
    '''
    Create a subscription lock.
    '''
    return call_az("az account lock create", locals())


def delete(ids=None, name=None, resource_group=None):
    '''
    Delete a subscription lock.
    '''
    return call_az("az account lock delete", locals())


def list(filter_string=None, resource_group=None):
    '''
    List lock information in the subscription.
    '''
    return call_az("az account lock list", locals())


def show(ids=None, name=None, resource_group=None):
    '''
    Show the details of a subscription lock
    '''
    return call_az("az account lock show", locals())


def update(ids=None, lock_type=None, name=None, notes=None, resource_group=None):
    '''
    Update a subscription lock.
    '''
    return call_az("az account lock update", locals())




from .... pyaz_utils import call_az

def show(name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    return call_az("az storage share metadata show", locals())


def update(name, account_key=None, account_name=None, connection_string=None, metadata=None, sas_token=None, timeout=None):
    return call_az("az storage share metadata update", locals())




from .... pyaz_utils import call_az

def create(address_prefix, appliance_name, name, resource_group, allow=None, default=None, optimize=None):
    '''
    Create an Azure network virtual appliance site.
    '''
    return call_az("az network virtual-appliance site create", locals())


def update(address_prefix, appliance_name, name, resource_group, add=None, allow=None, default=None, force_string=None, optimize=None, remove=None, set=None):
    '''
    Update an Azure network virtual appliance site.
    '''
    return call_az("az network virtual-appliance site update", locals())


def show(appliance_name, name, resource_group):
    '''
    Show the detail of an Azure network virtual appliance site.
    '''
    return call_az("az network virtual-appliance site show", locals())


def delete(appliance_name, name, resource_group, yes=None):
    '''
    Delete an Azure network virtual appliance site.
    '''
    return call_az("az network virtual-appliance site delete", locals())


def list(appliance_name, resource_group):
    '''
    List all Azure network virtual appliance site.
    '''
    return call_az("az network virtual-appliance site list", locals())




from ... pyaz_utils import call_az

def create(account_name, archive_window_length, asset_name, live_event_name, name, resource_group, description=None, fragments_per_ts_segment=None, manifest_name=None, output_snap_time=None):
    '''
    Create a live output.
    '''
    return call_az("az ams live-output create", locals())


def show(account_name, live_event_name, name, resource_group):
    '''
    Show the details of a live output.
    '''
    return call_az("az ams live-output show", locals())


def list(account_name, live_event_name, resource_group):
    '''
    List all the live outputs in a live event.
    '''
    return call_az("az ams live-output list", locals())


def delete(account_name, live_event_name, name, resource_group):
    '''
    Delete a live output.
    '''
    return call_az("az ams live-output delete", locals())




from ... pyaz_utils import call_az

def list(account_name, invoice_section_name=None, profile_name=None):
    '''
    List the role definitions for a billing account. The operation is supported for billing accounts with agreement type Microsoft Partner Agreement or Microsoft Customer Agreement.
    '''
    return call_az("az billing role-definition list", locals())


def show(account_name, name, invoice_section_name=None, profile_name=None):
    '''
    Show the role definition details
    '''
    return call_az("az billing role-definition show", locals())




from ... pyaz_utils import call_az
from . import access_policy, certificate, linked_hub


def list(resource_group=None):
    '''
    List Azure IoT Hub device provisioning services.
    '''
    return call_az("az iot dps list", locals())


def show(name, resource_group=None):
    '''
    Get the details of an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps show", locals())


def create(name, resource_group, location=None, sku=None, tags=None, unit=None):
    '''
    Create an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps create", locals())


def delete(name, resource_group):
    '''
    Delete an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps delete", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update an Azure IoT Hub device provisioning service.
    '''
    return call_az("az iot dps update", locals())




from .. pyaz_utils import call_az
from . import arm_template, artifact, artifact_source, custom_image, environment, formula, gallery_image, secret, vm, vnet


def get(name, resource_group, expand=None):
    return call_az("az lab get", locals())


def delete(name, resource_group):
    return call_az("az lab delete", locals())




from .... pyaz_utils import call_az
from . import metadata


def create(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, metadata=None, permissions=None, sas_token=None, timeout=None, umask=None):
    '''
    Create a directory in ADLS Gen2 file system.
    '''
    return call_az("az storage fs directory create", locals())


def exists(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Check for the existence of a directory in ADLS Gen2 file system.
    '''
    return call_az("az storage fs directory exists", locals())


def show(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Show properties of a directory in ADLS Gen2 file system.
    '''
    return call_az("az storage fs directory show", locals())


def delete(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None, yes=None):
    '''
    Delete a directory in ADLS Gen2 file system.
    '''
    return call_az("az storage fs directory delete", locals())


def move(name, new_directory, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Move a directory in ADLS Gen2 file system.
    '''
    return call_az("az storage fs directory move", locals())


def list(account_key=None, account_name=None, auth_mode=None, connection_string=None, num_results=None, path=None, recursive=None, sas_token=None, timeout=None):
    '''
    List directories in ADLS Gen2 file system.
    '''
    return call_az("az storage fs directory list", locals())


def upload(file_system, source, account_key=None, account_name=None, auth_mode=None, connection_string=None, destination_path=None, recursive=None, sas_token=None):
    '''
    Upload files or subdirectories to a directory in ADLS Gen2 file system.
    '''
    return call_az("az storage fs directory upload", locals())


def download(destination_path, file_system, account_key=None, account_name=None, auth_mode=None, connection_string=None, recursive=None, sas_token=None, source_path=None):
    '''
    Download files from the directory in ADLS Gen2 file system to a local file path.
    '''
    return call_az("az storage fs directory download", locals())




from ..... pyaz_utils import call_az

def list(name, namespace_name, resource_group, topic_name):
    '''
    List the keys and connection strings of Authorization Rule for Service Bus Topic.
    '''
    return call_az("az servicebus topic authorization-rule keys list", locals())


def renew(name, namespace_name, resource_group, topic_name, key=None, key_value=None):
    '''
    Regenerate keys of Authorization Rule for Service Bus Topic.
    '''
    return call_az("az servicebus topic authorization-rule keys renew", locals())




from .... pyaz_utils import call_az

def list(name, resource_group):
    '''
    List shared access keys of a topic.
    '''
    return call_az("az eventgrid topic key list", locals())


def regenerate(key_name, name, resource_group):
    '''
    Regenerate a shared access key of a topic.
    '''
    return call_az("az eventgrid topic key regenerate", locals())




from ... pyaz_utils import call_az

def update(log, retention, services, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None, version=None):
    '''
    Update logging settings for a storage account.
    '''
    return call_az("az storage logging update", locals())


def show(account_key=None, account_name=None, connection_string=None, sas_token=None, services=None, timeout=None):
    '''
    Show logging settings for a storage account.
    '''
    return call_az("az storage logging show", locals())


def off(account_key=None, account_name=None, connection_string=None, sas_token=None, services=None, timeout=None):
    '''
    Turn off logging for a storage account.
    '''
    return call_az("az storage logging off", locals())




from ... pyaz_utils import call_az

def create(location, resource_group, service_topology_name, artifact_source=None, tags=None):
    '''
    Creates a service topology.
    '''
    return call_az("az deploymentmanager service-topology create", locals())


def delete(resource_group, service_topology_name):
    '''
    Deletes the service topology.
    '''
    return call_az("az deploymentmanager service-topology delete", locals())


def show(resource_group, service_topology_name):
    '''
    Get the details of a service topology.
    '''
    return call_az("az deploymentmanager service-topology show", locals())


def list(resource_group):
    '''
    List all service topologies in a resource group.
    '''
    return call_az("az deploymentmanager service-topology list", locals())


def update(resource_group, service_topology_name, add=None, artifact_source=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Updates the service topology.
    '''
    return call_az("az deploymentmanager service-topology update", locals())




from ... pyaz_utils import call_az

def show(profile_name, resource_group):
    '''
    Show details of an AFD profile.
    '''
    return call_az("az afd profile show", locals())


def delete(profile_name, resource_group):
    '''
    Delete an AFD profile.
    '''
    return call_az("az afd profile delete", locals())


def update(profile_name, resource_group, tags):
    '''
    Update an AFD profile.
    '''
    return call_az("az afd profile update", locals())


def list(resource_group=None):
    '''
    List AFD profiles.
    '''
    return call_az("az afd profile list", locals())


def create(profile_name, resource_group, sku, tags=None):
    '''
    Create a new AFD profile.
    '''
    return call_az("az afd profile create", locals())


def usage(profile_name, resource_group):
    '''
    List resource usage within the specific AFD profile.
    '''
    return call_az("az afd profile usage", locals())




from ... pyaz_utils import call_az

def list(expand=None):
    '''
    List the billing accounts that a user has access to.
    '''
    return call_az("az billing account list", locals())


def show(name, expand=None):
    '''
    Get a billing account by its ID.
    '''
    return call_az("az billing account show", locals())


def update(name, billing_profiles_value=None, departments=None, display_name=None, enrollment_accounts=None, no_wait=None, sold_to=None):
    '''
    Update the properties of a billing account. Currently, displayName and address can be updated. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.
    '''
    return call_az("az billing account update", locals())


def wait(name, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the billing account is met.
    '''
    return call_az("az billing account wait", locals())




from ... pyaz_utils import call_az

def create(cluster_name, name, resource_group, hot_cache_period=None, no_wait=None, soft_delete_period=None):
    '''
    Create a Kusto database.
    '''
    return call_az("az kusto database create", locals())


def delete(cluster_name, name, resource_group, yes=None):
    '''
    Delete a Kusto database.
    '''
    return call_az("az kusto database delete", locals())


def update(cluster_name, name, resource_group, soft_delete_period, add=None, force_string=None, hot_cache_period=None, no_wait=None, remove=None, set=None):
    '''
    Update a Kusto database.
    '''
    return call_az("az kusto database update", locals())


def list(cluster_name, resource_group):
    '''
    List a Kusto database.
    '''
    return call_az("az kusto database list", locals())


def show(cluster_name, name, resource_group):
    '''
    Get a Kusto database.
    '''
    return call_az("az kusto database show", locals())


def wait(cluster_name, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for a managed Kusto database to reach a desired state.
    '''
    return call_az("az kusto database wait", locals())




from .... pyaz_utils import call_az

def create(address_prefixes, name, resource_group, vnet_name, delegations=None, disable_private_endpoint_network_policies=None, disable_private_link_service_network_policies=None, nat_gateway=None, network_security_group=None, route_table=None, service_endpoint_policy=None, service_endpoints=None):
    '''
    Create a subnet and associate an existing NSG and route table.
    '''
    return call_az("az network vnet subnet create", locals())


def delete(name, resource_group, vnet_name):
    '''
    Delete a subnet.
    '''
    return call_az("az network vnet subnet delete", locals())


def show(name, resource_group, vnet_name, expand=None):
    '''
    Show details of a subnet.
    '''
    return call_az("az network vnet subnet show", locals())


def list(resource_group, vnet_name):
    '''
    List the subnets in a virtual network.
    '''
    return call_az("az network vnet subnet list", locals())


def update(name, resource_group, vnet_name, add=None, address_prefixes=None, delegations=None, disable_private_endpoint_network_policies=None, disable_private_link_service_network_policies=None, force_string=None, nat_gateway=None, network_security_group=None, remove=None, route_table=None, service_endpoint_policy=None, service_endpoints=None, set=None):
    '''
    Update a subnet.
    '''
    return call_az("az network vnet subnet update", locals())


def list_available_delegations(location=None, resource_group=None):
    '''
    List the services available for subnet delegation.
    '''
    return call_az("az network vnet subnet list-available-delegations", locals())




from .... pyaz_utils import call_az

def update(cluster_name, reliability_level, resource_group, auto_add_node=None):
    '''
    Update the reliability tier for the primary node in a cluster.
    '''
    return call_az("az sf cluster reliability update", locals())




from .... pyaz_utils import call_az

def create(account, credential_name, database_name, uri, user_name, password=None):
    '''
    Create a new catalog credential for use with an external data source.
    '''
    return call_az("az dla catalog credential create", locals())


def show(account, credential_name, database_name):
    '''
    Retrieve a catalog credential.
    '''
    return call_az("az dla catalog credential show", locals())


def update(account, credential_name, database_name, uri, user_name, new_password=None, password=None):
    '''
    Update a catalog credential for use with an external data source.
    '''
    return call_az("az dla catalog credential update", locals())


def list(account, database_name, count=None, filter=None, orderby=None, select=None, skip=None, top=None):
    '''
    List catalog credentials.
    '''
    return call_az("az dla catalog credential list", locals())


def delete(account, credential_name, database_name, cascade=None, password=None):
    '''
    Delete a catalog credential.
    '''
    return call_az("az dla catalog credential delete", locals())




from .... pyaz_utils import call_az
from . import event_subscription


def show(name, resource_group):
    '''
    Get the details of a partner topic.
    '''
    return call_az("az eventgrid partner topic show", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a partner topic.
    '''
    return call_az("az eventgrid partner topic delete", locals())


def activate(name, resource_group):
    '''
    Activate a partner topic.
    '''
    return call_az("az eventgrid partner topic activate", locals())


def deactivate(name, resource_group):
    '''
    Deactivate a partner topic.
    '''
    return call_az("az eventgrid partner topic deactivate", locals())


def list(odata_query=None, resource_group=None):
    '''
    List available partner topics.
    '''
    return call_az("az eventgrid partner topic list", locals())




from ... pyaz_utils import call_az
from . import condition


def create(cluster_name, resource_group, type, days=None, max_workernode_count=None, min_workernode_count=None, no_wait=None, time=None, timezone=None, workernode_count=None, yes=None):
    '''
    Enable Autoscale for a running cluster.
    '''
    return call_az("az hdinsight autoscale create", locals())


def update(cluster_name, resource_group, max_workernode_count=None, min_workernode_count=None, no_wait=None, timezone=None):
    '''
    Update the Autoscale configuration.
    '''
    return call_az("az hdinsight autoscale update", locals())


def show(cluster_name, resource_group):
    '''
    Get the Autoscale configuration of a specified cluster.
    '''
    return call_az("az hdinsight autoscale show", locals())


def delete(cluster_name, resource_group, no_wait=None, yes=None):
    '''
    Disable Autoscale for a running cluster.
    '''
    return call_az("az hdinsight autoscale delete", locals())


def list_timezones():
    '''
    List the available timezone name when enabling Schedule-based Autoscale.
    '''
    return call_az("az hdinsight autoscale list-timezones", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until an operation is complete.
    '''
    return call_az("az hdinsight autoscale wait", locals())




from .... pyaz_utils import call_az

def add(action_name, profile_name, resource_group, rule_name, rule_set_name, cache_behavior=None, cache_duration=None, custom_fragment=None, custom_hostname=None, custom_path=None, custom_querystring=None, destination=None, header_action=None, header_name=None, header_value=None, preserve_unmatched_path=None, query_parameters=None, query_string_behavior=None, redirect_protocol=None, redirect_type=None, source_pattern=None):
    '''
    Add an action to a delivery rule.
    '''
    return call_az("az afd rule action add", locals())


def remove(index, profile_name, resource_group, rule_name, rule_set_name):
    '''
    Remove an action from a delivery rule.
    '''
    return call_az("az afd rule action remove", locals())


def list(profile_name, resource_group, rule_name, rule_set_name):
    '''
    show actions asscociated with the rule.
    '''
    return call_az("az afd rule action list", locals())




from ... pyaz_utils import call_az

def attach(name, resource_group, vm_name, caching=None, enable_write_accelerator=None, lun=None, new=None, size_gb=None, sku=None):
    '''
    Attach a managed persistent disk to a VM. Please note that --ids only supports one disk.
    '''
    return call_az("az vm disk attach", locals())


def detach(name, resource_group, vm_name):
    '''
    Detach a managed disk from a VM.
    '''
    return call_az("az vm disk detach", locals())




from .... pyaz_utils import call_az

def invoke(code, language, session_id, spark_pool_name, workspace_name):
    '''
    Invoke a Spark statement.
    '''
    return call_az("az synapse spark statement invoke", locals())


def list(session_id, spark_pool_name, workspace_name):
    '''
    List all Spark statements
    '''
    return call_az("az synapse spark statement list", locals())


def show(livy_id, session_id, spark_pool_name, workspace_name):
    '''
    Get a Spark statement.
    '''
    return call_az("az synapse spark statement show", locals())


def cancel(livy_id, session_id, spark_pool_name, workspace_name, yes=None):
    '''
    Cancel a Spark statement.
    '''
    return call_az("az synapse spark statement cancel", locals())




from .. pyaz_utils import call_az

def create(lock_type, name, namespace=None, notes=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Create a lock.
    '''
    return call_az("az lock create", locals())


def delete(ids=None, name=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Delete a lock.
    '''
    return call_az("az lock delete", locals())


def list(filter_string=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    List lock information.
    '''
    return call_az("az lock list", locals())


def show(ids=None, name=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Show the properties of a lock
    '''
    return call_az("az lock show", locals())


def update(ids=None, lock_type=None, name=None, namespace=None, notes=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Update a lock.
    '''
    return call_az("az lock update", locals())




from .... pyaz_utils import call_az
from . import keys


def create(hybrid_connection_name, name, namespace_name, resource_group, rights=None):
    '''
    Create Authorization Rule for given Relay Service Hybrid Connection
    '''
    return call_az("az relay hyco authorization-rule create", locals())


def show(hybrid_connection_name, name, namespace_name, resource_group):
    '''
    Shows the details of Authorization Rule for given Relay Service Hybrid Connection
    '''
    return call_az("az relay hyco authorization-rule show", locals())


def list(hybrid_connection_name, namespace_name, resource_group):
    '''
    shows list of Authorization Rule by Relay Service Hybrid Connection
    '''
    return call_az("az relay hyco authorization-rule list", locals())


def delete(hybrid_connection_name, name, namespace_name, resource_group):
    '''
    Deletes the Authorization Rule of the given Relay Service Hybrid Connection.
    '''
    return call_az("az relay hyco authorization-rule delete", locals())


def update(hybrid_connection_name, name, namespace_name, resource_group, rights, add=None, force_string=None, remove=None, set=None):
    '''
    Create Authorization Rule for given Relay Service Hybrid Connection
    '''
    return call_az("az relay hyco authorization-rule update", locals())




from ... pyaz_utils import call_az

def create(file, name, workspace_name, no_wait=None):
    '''
    Create a pipeline.
    '''
    return call_az("az synapse pipeline create", locals())


def set(file, name, workspace_name, no_wait=None):
    '''
    Update an exist pipeline.
    '''
    return call_az("az synapse pipeline set", locals())


def update(file, name, workspace_name, no_wait=None):
    '''
    Update an exist pipeline.
    '''
    return call_az("az synapse pipeline update", locals())


def list(workspace_name):
    '''
    List pipelines.
    '''
    return call_az("az synapse pipeline list", locals())


def show(name, workspace_name):
    '''
    Get a pipeline.
    '''
    return call_az("az synapse pipeline show", locals())


def delete(name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a pipeline.
    '''
    return call_az("az synapse pipeline delete", locals())


def create_run(name, workspace_name, is_recovery=None, parameters=None, reference_pipeline_run_id=None, start_activity_name=None):
    '''
    Creates a run of a pipeline.
    '''
    return call_az("az synapse pipeline create-run", locals())




from .... pyaz_utils import call_az

def create(name, resource_group, subdomain, display_name=None, location=None, no_wait=None, sku=None, template=None):
    '''
    Create an IoT Central application.
    '''
    return call_az("az iot central app create", locals())


def list(resource_group=None):
    '''
    List IoT Central applications.
    '''
    return call_az("az iot central app list", locals())


def show(name, resource_group=None):
    '''
    Get the details of an IoT Central application.
    '''
    return call_az("az iot central app show", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update metadata for an IoT Central application.
    '''
    return call_az("az iot central app update", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete an IoT Central application.
    '''
    return call_az("az iot central app delete", locals())




from .... pyaz_utils import call_az

def create(account_name, body, container_name, database_name, name, resource_group):
    '''
    Create an SQL user defined function under an Azure Cosmos DB SQL container.
    '''
    return call_az("az cosmosdb sql user-defined-function create", locals())


def update(account_name, body, container_name, database_name, name, resource_group):
    return call_az("az cosmosdb sql user-defined-function update", locals())


def list(account_name, container_name, database_name, resource_group):
    '''
    List the SQL user defined functions under an Azure Cosmos DB SQL container.
    '''
    return call_az("az cosmosdb sql user-defined-function list", locals())


def show(account_name, container_name, database_name, name, resource_group):
    '''
    Show the details of a SQL user defined function under an Azure Cosmos DB SQL container.
    '''
    return call_az("az cosmosdb sql user-defined-function show", locals())


def delete(account_name, container_name, database_name, name, resource_group, yes=None):
    '''
    Delete the SQL user defined function under an Azure Cosmos DB SQL container.
    '''
    return call_az("az cosmosdb sql user-defined-function delete", locals())




from .... pyaz_utils import call_az

def create(name, resource_group, location=None, tags=None):
    '''
    Create a service endpoint policy.
    '''
    return call_az("az network service-endpoint policy create", locals())


def delete(name, resource_group):
    '''
    Delete a service endpoint policy.
    '''
    return call_az("az network service-endpoint policy delete", locals())


def list(resource_group=None):
    '''
    List service endpoint policies.
    '''
    return call_az("az network service-endpoint policy list", locals())


def show(name, resource_group):
    '''
    Get the details of a service endpoint policy.
    '''
    return call_az("az network service-endpoint policy show", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update a service endpoint policy.
    '''
    return call_az("az network service-endpoint policy update", locals())




from ... pyaz_utils import call_az

def show(location, name, resource_group):
    return call_az("az sql instance-failover-group show", locals())


def create(name, partner_mi, partner_resource_group, resource_group, source_mi, failover_policy=None, grace_period=None):
    '''
    Creates an instance failover group between two connected managed instances.
    '''
    return call_az("az sql instance-failover-group create", locals())


def update(location, name, resource_group, add=None, failover_policy=None, force_string=None, grace_period=None, remove=None, set=None):
    '''
    Updates the instance failover group.
    '''
    return call_az("az sql instance-failover-group update", locals())


def delete(location, name, resource_group):
    return call_az("az sql instance-failover-group delete", locals())


def set_primary(location, name, resource_group, allow_data_loss=None):
    '''
    Set the primary of the instance failover group by failing over all databases from the current primary managed instance.
    '''
    return call_az("az sql instance-failover-group set-primary", locals())




from ... pyaz_utils import call_az

def list():
    '''
    List security settings.
    '''
    return call_az("az security setting list", locals())


def show(name):
    '''
    Shows a security setting.
    '''
    return call_az("az security setting show", locals())


def update(enabled, name):
    '''
    Updates a security setting.
    '''
    return call_az("az security setting update", locals())




from .... pyaz_utils import call_az

def set(name, resource_group, docker_custom_image_name=None, docker_registry_server_password=None, docker_registry_server_url=None, docker_registry_server_user=None, slot=None):
    '''
    Set an existing function app's container settings.
    '''
    return call_az("az functionapp config container set", locals())


def delete(name, resource_group, slot=None):
    '''
    Delete an existing function app's container settings.
    '''
    return call_az("az functionapp config container delete", locals())


def show(name, resource_group, slot=None):
    '''
    Get details of a function app's container settings.
    '''
    return call_az("az functionapp config container show", locals())




from ... pyaz_utils import call_az
from . import subscription


def list(no_register=None):
    '''
    List all management groups.
    '''
    return call_az("az account management-group list", locals())


def show(name, expand=None, no_register=None, recurse=None):
    '''
    Get a specific management group.
    '''
    return call_az("az account management-group show", locals())


def create(name, display_name=None, no_register=None, parent=None):
    '''
    Create a new management group.
    '''
    return call_az("az account management-group create", locals())


def delete(name, no_register=None):
    '''
    Delete an existing management group.
    '''
    return call_az("az account management-group delete", locals())


def update(name, add=None, display_name=None, force_string=None, parent=None, remove=None, set=None):
    '''
    Update an existing management group.
    '''
    return call_az("az account management-group update", locals())




from .... pyaz_utils import call_az

def create(application_name, name, package_file, resource_group, version_name):
    '''
    Create a Batch application package record and activate it.
    '''
    return call_az("az batch application package create", locals())


def delete(application_name, name, resource_group, version_name, yes=None):
    return call_az("az batch application package delete", locals())


def show(application_name, name, resource_group, version_name):
    return call_az("az batch application package show", locals())


def activate(application_name, format, name, resource_group, version_name):
    '''
    Activates a Batch application package.
    '''
    return call_az("az batch application package activate", locals())


def list(application_name, name, resource_group, maxresults=None):
    return call_az("az batch application package list", locals())




from ..... pyaz_utils import call_az

def create(name, namespace_name, resource_group, subscription_name, topic_name, action_compatibility_level=None, action_sql_expression=None, content_type=None, correlation_id=None, enable_action_preprocessing=None, enable_correlation_preprocessing=None, enable_sql_preprocessing=None, filter_sql_expression=None, label=None, message_id=None, reply_to=None, reply_to_session_id=None, session_id=None, to=None):
    '''
    Create the ServiceBus Rule for Subscription
    '''
    return call_az("az servicebus topic subscription rule create", locals())


def show(name, namespace_name, resource_group, subscription_name, topic_name):
    '''
    Shows ServiceBus Rule Details
    '''
    return call_az("az servicebus topic subscription rule show", locals())


def list(namespace_name, resource_group, subscription_name, topic_name, skip=None, top=None):
    '''
    List the ServiceBus Rule by Subscription
    '''
    return call_az("az servicebus topic subscription rule list", locals())


def delete(name, namespace_name, resource_group, subscription_name, topic_name):
    '''
    Deletes the ServiceBus Rule
    '''
    return call_az("az servicebus topic subscription rule delete", locals())


def update(name, namespace_name, resource_group, subscription_name, topic_name, action_compatibility_level=None, action_sql_expression=None, add=None, content_type=None, correlation_id=None, enable_action_preprocessing=None, enable_correlation_preprocessing=None, enable_sql_preprocessing=None, filter_sql_expression=None, force_string=None, label=None, message_id=None, remove=None, reply_to=None, reply_to_session_id=None, session_id=None, set=None, to=None):
    '''
    Updates the ServiceBus Rule for Subscription
    '''
    return call_az("az servicebus topic subscription rule update", locals())




from ... pyaz_utils import call_az

def set(distribution, name, resource_group):
    '''
    Configure routing traffic to deployment slots.
    '''
    return call_az("az webapp traffic-routing set", locals())


def show(name, resource_group):
    '''
    Display the current distribution of traffic across slots.
    '''
    return call_az("az webapp traffic-routing show", locals())


def clear(name, resource_group):
    '''
    Clear the routing rules and send all traffic to production.
    '''
    return call_az("az webapp traffic-routing clear", locals())




from ... pyaz_utils import call_az
from . import key, topic


def show(name, resource_group):
    '''
    Get the details of a domain.
    '''
    return call_az("az eventgrid domain show", locals())


def list(odata_query=None, resource_group=None):
    '''
    List available domains.
    '''
    return call_az("az eventgrid domain list", locals())


def create(name, resource_group, identity=None, inbound_ip_rules=None, input_mapping_default_values=None, input_mapping_fields=None, input_schema=None, location=None, public_network_access=None, sku=None, tags=None):
    '''
    Create a domain.
    '''
    return call_az("az eventgrid domain create", locals())


def delete(name, resource_group):
    '''
    Delete a domain.
    '''
    return call_az("az eventgrid domain delete", locals())


def update(name, resource_group, identity=None, inbound_ip_rules=None, public_network_access=None, sku=None, tags=None):
    '''
    Update a domain.
    '''
    return call_az("az eventgrid domain update", locals())




from .... pyaz_utils import call_az

def show(location, name, publisher, version):
    return call_az("az vmss extension image show", locals())


def list_names(location, publisher):
    return call_az("az vmss extension image list-names", locals())


def list_versions(location, name, publisher, filter=None, orderby=None, top=None):
    return call_az("az vmss extension image list-versions", locals())


def list(latest=None, location=None, name=None, publisher=None, version=None):
    '''
    List the information on available extensions.
    '''
    return call_az("az vmss extension image list", locals())




from .. pyaz_utils import call_az
from . import custom_domain, edge_node, endpoint, origin, origin_group, profile


def name_exists(name):
    '''
    Check the availability of a resource name. This is needed for resources where name is globally unique, such as a CDN endpoint.
    '''
    return call_az("az cdn name-exists", locals())


def usage():
    return call_az("az cdn usage", locals())




from .... pyaz_utils import call_az
from . import endpoint, output, test_configuration, test_group


def create(name, dest_address=None, dest_port=None, dest_resource=None, do_not_start=None, endpoint_dest_address=None, endpoint_dest_coverage_level=None, endpoint_dest_name=None, endpoint_dest_resource_id=None, endpoint_dest_type=None, endpoint_source_address=None, endpoint_source_coverage_level=None, endpoint_source_name=None, endpoint_source_resource_id=None, endpoint_source_type=None, frequency=None, http_method=None, http_path=None, http_port=None, http_valid_status_codes=None, https_prefer=None, icmp_disable_trace_route=None, location=None, monitoring_interval=None, notes=None, output_type=None, preferred_ip_version=None, protocol=None, resource_group=None, source_port=None, source_resource=None, tags=None, tcp_disable_trace_route=None, tcp_port=None, tcp_port_behavior=None, test_config_name=None, test_group_disable=None, test_group_name=None, threshold_failed_percent=None, threshold_round_trip_time=None, workspace_ids=None):
    '''
    Create a connection monitor.
    '''
    return call_az("az network watcher connection-monitor create", locals())


def delete(location, name, resource_group=None):
    '''
    Delete a connection monitor for the given region.
    '''
    return call_az("az network watcher connection-monitor delete", locals())


def show(location, name, resource_group=None):
    '''
    Shows a connection monitor by name.
    '''
    return call_az("az network watcher connection-monitor show", locals())


def stop(location, name, resource_group=None):
    '''
    Stop the specified connection monitor.
    '''
    return call_az("az network watcher connection-monitor stop", locals())


def start(location, name, resource_group=None):
    '''
    Start the specified connection monitor.
    '''
    return call_az("az network watcher connection-monitor start", locals())


def query(location, name, resource_group=None):
    '''
    Query a snapshot of the most recent connection state of a connection monitor.
    '''
    return call_az("az network watcher connection-monitor query", locals())


def list(location, resource_group=None):
    '''
    List connection monitors for the given region.
    '''
    return call_az("az network watcher connection-monitor list", locals())




from .... pyaz_utils import call_az
from . import identity, link, location


def create(name, resource_group, bandwidth=None, encapsulation=None, location=None, peering_location=None, tags=None):
    '''
    Create an ExpressRoute port.
    '''
    return call_az("az network express-route port create", locals())


def delete(name, resource_group):
    '''
    Delete an ExpressRoute port.
    '''
    return call_az("az network express-route port delete", locals())


def list(resource_group=None):
    '''
    List ExpressRoute ports.
    '''
    return call_az("az network express-route port list", locals())


def show(name, resource_group):
    '''
    Get the details of an ExpressRoute port.
    '''
    return call_az("az network express-route port show", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update settings of an ExpressRoute port.
    '''
    return call_az("az network express-route port update", locals())


def generate_loa(customer_name, name, resource_group, file=None):
    '''
    Generate and download a letter of authorization for the requested ExpressRoutePort
    '''
    return call_az("az network express-route port generate-loa", locals())




from ... pyaz_utils import call_az

def list(resource_group=None):
    '''
    List budgets for an Azure subscription.
    '''
    return call_az("az consumption budget list", locals())


def show(budget_name, resource_group=None):
    '''
    Show budget for an Azure subscription.
    '''
    return call_az("az consumption budget show", locals())


def create(amount, budget_name, category, end_date, start_date, time_grain, meter_filter=None, resource_filter=None, resource_group=None, resource_group_filter=None):
    '''
    Create a budget for an Azure subscription.
    '''
    return call_az("az consumption budget create", locals())


def delete(budget_name, resource_group=None):
    '''
    Delete a budget for an Azure subscription.
    '''
    return call_az("az consumption budget delete", locals())




from .. pyaz_utils import call_az

def create(name, resource_group, accelerated_network=None, disk_access=None, disk_encryption_set=None, disk_iops_read_only=None, disk_iops_read_write=None, disk_mbps_read_only=None, disk_mbps_read_write=None, edge_zone=None, enable_bursting=None, encryption_type=None, for_upload=None, gallery_image_reference=None, gallery_image_reference_lun=None, hyper_v_generation=None, image_reference=None, image_reference_lun=None, location=None, logical_sector_size=None, max_shares=None, network_access_policy=None, no_wait=None, os_type=None, public_network_access=None, security_type=None, size_gb=None, sku=None, source=None, source_storage_account_id=None, support_hibernation=None, tags=None, tier=None, upload_size_bytes=None, zone=None):
    '''
    Create a managed disk.
    '''
    return call_az("az disk create", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a managed disk.
    '''
    return call_az("az disk delete", locals())


def grant_access(duration_in_seconds, name, resource_group, access_level=None):
    '''
    Grant a resource access to a managed disk.
    '''
    return call_az("az disk grant-access", locals())


def list(resource_group=None):
    '''
    List managed disks.
    '''
    return call_az("az disk list", locals())


def revoke_access(name, resource_group):
    '''
    Revoke a resource's read access to a managed disk.
    '''
    return call_az("az disk revoke-access", locals())


def show(name, resource_group):
    return call_az("az disk show", locals())


def update(name, resource_group, accelerated_network=None, add=None, disk_access=None, disk_encryption_set=None, disk_iops_read_only=None, disk_iops_read_write=None, disk_mbps_read_only=None, disk_mbps_read_write=None, enable_bursting=None, encryption_type=None, force_string=None, max_shares=None, network_access_policy=None, no_wait=None, public_network_access=None, remove=None, set=None, size_gb=None, sku=None):
    '''
    Update a managed disk.
    '''
    return call_az("az disk update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a managed disk is met.
    '''
    return call_az("az disk wait", locals())




from ..... pyaz_utils import call_az
from . import ipv6_config


def create(address_prefix, circuit_name, name, peer_circuit, peering_name, resource_group, authorization_key=None):
    '''
    Create connections between two ExpressRoute circuits.
    '''
    return call_az("az network express-route peering connection create", locals())


def delete(circuit_name, name, peering_name, resource_group):
    '''
    Delete an ExpressRoute circuit connection.
    '''
    return call_az("az network express-route peering connection delete", locals())


def show(circuit_name, name, peering_name, resource_group):
    '''
    Get the details of an ExpressRoute circuit connection.
    '''
    return call_az("az network express-route peering connection show", locals())


def list(circuit_name, peering_name, resource_group):
    '''
    List all global reach connections associated with a private peering in an express route circuit.
    '''
    return call_az("az network express-route peering connection list", locals())




from ... pyaz_utils import call_az
from . import address_pool, auth_cert, client_cert, frontend_ip, frontend_port, http_listener, http_settings, identity, private_link, probe, redirect_config, root_cert, rule, ssl_cert, ssl_policy, ssl_profile, url_path_map, waf_config, waf_policy


def create(name, resource_group, capacity=None, cert_file=None, cert_password=None, connection_draining_timeout=None, custom_error_pages=None, enable_private_link=None, frontend_port=None, http2=None, http_settings_cookie_based_affinity=None, http_settings_port=None, http_settings_protocol=None, identity=None, key_vault_secret_id=None, location=None, max_capacity=None, min_capacity=None, no_wait=None, private_ip_address=None, private_link_ip_address=None, private_link_primary=None, private_link_subnet=None, private_link_subnet_prefix=None, public_ip_address=None, public_ip_address_allocation=None, routing_rule_type=None, servers=None, sku=None, ssl_certificate_name=None, ssl_profile=None, ssl_profile_id=None, subnet=None, subnet_address_prefix=None, tags=None, trusted_client_cert=None, validate=None, vnet_address_prefix=None, vnet_name=None, waf_policy=None, zones=None):
    '''
    Create an application gateway.
    '''
    return call_az("az network application-gateway create", locals())


def delete(name, resource_group, no_wait=None):
    '''
    Delete an application gateway.
    '''
    return call_az("az network application-gateway delete", locals())


def show(name, resource_group):
    '''
    Get the details of an application gateway.
    '''
    return call_az("az network application-gateway show", locals())


def list(resource_group=None):
    '''
    List application gateways.
    '''
    return call_az("az network application-gateway list", locals())


def start(name, resource_group):
    '''
    Start an application gateway.
    '''
    return call_az("az network application-gateway start", locals())


def stop(name, resource_group):
    '''
    Stop an application gateway.
    '''
    return call_az("az network application-gateway stop", locals())


def show_backend_health(name, resource_group, address_pool=None, expand=None, host=None, host_name_from_http_settings=None, http_settings=None, match_body=None, match_status_codes=None, path=None, protocol=None, timeout=None):
    '''
    Get information on the backend health of an application gateway.
    '''
    return call_az("az network application-gateway show-backend-health", locals())


def update(name, resource_group, add=None, capacity=None, custom_error_pages=None, force_string=None, http2=None, max_capacity=None, min_capacity=None, no_wait=None, remove=None, set=None, sku=None, tags=None):
    '''
    Update an application gateway.
    '''
    return call_az("az network application-gateway update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the application gateway is met.
    '''
    return call_az("az network application-gateway wait", locals())




from .... pyaz_utils import call_az

def check_dns(name, type=None):
    '''
    Check the availability of a relative DNS name.
    '''
    return call_az("az network traffic-manager profile check-dns", locals())


def show(name, resource_group):
    '''
    Get the details of a traffic manager profile.
    '''
    return call_az("az network traffic-manager profile show", locals())


def delete(name, resource_group):
    '''
    Delete a traffic manager profile.
    '''
    return call_az("az network traffic-manager profile delete", locals())


def list(resource_group=None):
    '''
    List traffic manager profiles.
    '''
    return call_az("az network traffic-manager profile list", locals())


def create(name, resource_group, routing_method, unique_dns_name, custom_headers=None, interval=None, max_failures=None, max_return=None, path=None, port=None, protocol=None, status=None, status_code_ranges=None, tags=None, timeout=None, ttl=None):
    '''
    Create a traffic manager profile.
    '''
    return call_az("az network traffic-manager profile create", locals())


def update(name, resource_group, add=None, custom_headers=None, force_string=None, interval=None, max_failures=None, max_return=None, path=None, port=None, protocol=None, remove=None, routing_method=None, set=None, status=None, status_code_ranges=None, tags=None, timeout=None, ttl=None):
    '''
    Update a traffic manager profile.
    '''
    return call_az("az network traffic-manager profile update", locals())




from ... pyaz_utils import call_az

def create(cluster_name, delegated_management_subnet_id, location, resource_group, authentication_method=None, cassandra_version=None, client_certificates=None, cluster_name_override=None, external_gossip_certificates=None, external_seed_nodes=None, hours_between_backups=None, identity_type=None, initial_cassandra_admin_password=None, no_wait=None, repair_enabled=None, restore_from_backup_id=None, tags=None):
    '''
    Create a Managed Cassandra Cluster.
    '''
    return call_az("az managed-cassandra cluster create", locals())


def update(cluster_name, resource_group, authentication_method=None, cassandra_version=None, client_certificates=None, external_gossip_certificates=None, external_seed_nodes=None, hours_between_backups=None, identity_type=None, no_wait=None, repair_enabled=None, tags=None):
    '''
    Update a Managed Cassandra Cluster.
    '''
    return call_az("az managed-cassandra cluster update", locals())


def deallocate(cluster_name, resource_group, no_wait=None):
    '''
    Deallocate the Managed Cassandra Cluster and Associated Data Centers. Deallocation will deallocate the host virtual machine of this cluster, and reserved the data disk. This won't do anything on an already deallocated cluster. Use Start to restart the cluster.
    '''
    return call_az("az managed-cassandra cluster deallocate", locals())


def invoke_command(cluster_name, command_name, host, resource_group, arguments=None, cassandra_stop_start=None, no_wait=None, readwrite=None):
    '''
    Invoke a command like nodetool for cassandra maintenance.
    '''
    return call_az("az managed-cassandra cluster invoke-command", locals())


def start(cluster_name, resource_group, no_wait=None):
    '''
    Start the Managed Cassandra Cluster and Associated Data Centers. Start will start the host virtual machine of this cluster with reserved data disk. This won't do anything on an already running cluster. Use Deallocate to deallocate the cluster.
    '''
    return call_az("az managed-cassandra cluster start", locals())


def status(cluster_name, resource_group):
    '''
    Gets the CPU, memory, and disk usage statistics for each Cassandra node in a cluster.
    '''
    return call_az("az managed-cassandra cluster status", locals())


def list(resource_group=None):
    '''
    List the Managed Cassandra Clusters in a ResourceGroup and Subscription. If the ResourceGroup is not specified all the clusters in this Subscription are returned.
    '''
    return call_az("az managed-cassandra cluster list", locals())


def show(cluster_name, resource_group):
    '''
    Get a Managed Cassandra Cluster Resource.
    '''
    return call_az("az managed-cassandra cluster show", locals())


def delete(cluster_name, resource_group, no_wait=None, yes=None):
    '''
    Deletes a Managed Cassandra Cluster.
    '''
    return call_az("az managed-cassandra cluster delete", locals())




from .... pyaz_utils import call_az

def show(name, resource_group, server):
    '''
    Show the current ledger digest settings.
    '''
    return call_az("az sql db ledger-digest-uploads show", locals())


def enable(endpoint, name, resource_group, server):
    '''
    Enable uploading ledger digests to an Azure Storage account or to Azure Confidential Ledger. If uploading ledger digests is already enabled, the cmdlet resets the digest storage endpoint to a new value.
    '''
    return call_az("az sql db ledger-digest-uploads enable", locals())


def disable(name, resource_group, server):
    '''
    Disable uploading ledger digests.
    '''
    return call_az("az sql db ledger-digest-uploads disable", locals())




from ... pyaz_utils import call_az

def create(key, name, resource_group, user_name, add_disabled=None, is_validated=None):
    '''
    Create the Kik Channel on a bot.
    '''
    return call_az("az bot kik create", locals())


def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Kik Channel on a bot
    '''
    return call_az("az bot kik show", locals())


def delete(name, resource_group):
    '''
    Delete the Kik Channel on a bot
    '''
    return call_az("az bot kik delete", locals())




from ... pyaz_utils import call_az

def list(account_name, customer_name=None, invoice_section_name=None, profile_name=None):
    '''
    List the billing permissions the caller has on a billing account.
    '''
    return call_az("az billing permission list", locals())




from ... pyaz_utils import call_az
from . import group, mg, sub, tenant


def list(name):
    '''
    List deployment operations at subscription scope.
    '''
    return call_az("az deployment operation list", locals())


def show(name, operation_ids):
    '''
    Show a deployment operation at subscription scope.
    '''
    return call_az("az deployment operation show", locals())




from ... pyaz_utils import call_az
from . import address_pool, frontend_ip, probe, rule


def show(name, resource_group, expand=None):
    return call_az("az network cross-region-lb show", locals())


def create(name, resource_group, backend_pool_name=None, frontend_ip_name=None, frontend_ip_zone=None, location=None, no_wait=None, public_ip_address=None, public_ip_address_allocation=None, public_ip_dns_name=None, public_ip_zone=None, tags=None, validate=None):
    '''
    Create a cross-region load balancer.
    '''
    return call_az("az network cross-region-lb create", locals())


def delete(name, resource_group):
    return call_az("az network cross-region-lb delete", locals())


def list(resource_group=None):
    '''
    List load balancers.
    '''
    return call_az("az network cross-region-lb list", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a cross-region load balancer.
    '''
    return call_az("az network cross-region-lb update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the cross-region load balancer is met.
    '''
    return call_az("az network cross-region-lb wait", locals())




from .... pyaz_utils import call_az
from . import condition, set


def create(gateway_name, name, resource_group, rule_set_name, enable_reroute=None, modified_path=None, modified_query_string=None, no_wait=None, request_headers=None, response_headers=None, sequence=None):
    '''
    Create a rewrite rule.
    '''
    return call_az("az network application-gateway rewrite-rule create", locals())


def show(gateway_name, name, resource_group, rule_set_name):
    '''
    Get the details of a rewrite rule.
    '''
    return call_az("az network application-gateway rewrite-rule show", locals())


def list(gateway_name, resource_group, rule_set_name):
    '''
    List rewrite rules.
    '''
    return call_az("az network application-gateway rewrite-rule list", locals())


def delete(gateway_name, name, resource_group, rule_set_name, no_wait=None):
    '''
    Delete a rewrite rule.
    '''
    return call_az("az network application-gateway rewrite-rule delete", locals())


def update(gateway_name, name, resource_group, rule_set_name, add=None, enable_reroute=None, force_string=None, modified_path=None, modified_query_string=None, no_wait=None, remove=None, request_headers=None, response_headers=None, sequence=None, set=None):
    '''
    Update a rewrite rule.
    '''
    return call_az("az network application-gateway rewrite-rule update", locals())


def list_request_headers():
    return call_az("az network application-gateway rewrite-rule list-request-headers", locals())


def list_response_headers():
    return call_az("az network application-gateway rewrite-rule list-response-headers", locals())




from ... pyaz_utils import call_az

def list(workspace_name):
    '''
    List spark job definitions.
    '''
    return call_az("az synapse spark-job-definition list", locals())


def show(name, workspace_name):
    '''
    Get a spark job definition.
    '''
    return call_az("az synapse spark-job-definition show", locals())


def delete(name, workspace_name, no_wait=None):
    '''
    Delete a spark job definition.
    '''
    return call_az("az synapse spark-job-definition delete", locals())


def create(file, name, workspace_name, folder_path=None, no_wait=None):
    '''
    Create a spark job definition.
    '''
    return call_az("az synapse spark-job-definition create", locals())


def wait(name, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a spark job definition is met.
    '''
    return call_az("az synapse spark-job-definition wait", locals())


def update(file, name, workspace_name, folder_path=None, no_wait=None):
    '''
    Update a spark job definition.
    '''
    return call_az("az synapse spark-job-definition update", locals())




from ... pyaz_utils import call_az

def show_execution_details(cluster_name, execution_id, resource_group):
    return call_az("az hdinsight script-action show-execution-details", locals())


def list(cluster_name, resource_group):
    return call_az("az hdinsight script-action list", locals())


def delete(cluster_name, name, resource_group):
    return call_az("az hdinsight script-action delete", locals())


def execute(cluster_name, name, resource_group, roles, script_uri, persist_on_success=None, script_parameters=None):
    '''
    Execute script actions on the specified HDInsight cluster.
    '''
    return call_az("az hdinsight script-action execute", locals())


def list_execution_history(cluster_name, resource_group):
    return call_az("az hdinsight script-action list-execution-history", locals())


def promote(cluster_name, execution_id, resource_group):
    return call_az("az hdinsight script-action promote", locals())




from ..... pyaz_utils import call_az

def add(name, resource_group, scope, reset=None):
    '''
    Add scopes to this activity log alert.
    '''
    return call_az("az monitor activity-log alert scope add", locals())


def remove(name, resource_group, scope):
    '''
    Removes scopes from this activity log alert.
    '''
    return call_az("az monitor activity-log alert scope remove", locals())




from ....... pyaz_utils import call_az

def add(match_variable, policy_name, resource_group, selector, selector_match_operator, type, version, group_name=None, rule_ids=None):
    '''
    Add a managed rule set to an exclusion.
    '''
    return call_az("az network application-gateway waf-policy managed-rule exclusion rule-set add", locals())


def remove(match_variable, policy_name, resource_group, selector, selector_match_operator, type, version, group_name=None):
    '''
    Remove managed rule set within an exclusion.
    '''
    return call_az("az network application-gateway waf-policy managed-rule exclusion rule-set remove", locals())


def list(policy_name, resource_group):
    '''
    List all managed rule sets of an exclusion.
    '''
    return call_az("az network application-gateway waf-policy managed-rule exclusion rule-set list", locals())




from .. pyaz_utils import call_az
from . import cors, identity, key, network_rule, upstream


def create(name, resource_group, sku, allowed_origins=None, default_action=None, enable_message_logs=None, location=None, service_mode=None, tags=None, unit_count=None):
    '''
    Creates a SignalR Service.
    '''
    return call_az("az signalr create", locals())


def delete(name, resource_group):
    '''
    Deletes a SignalR Service.
    '''
    return call_az("az signalr delete", locals())


def list(resource_group=None):
    '''
    Lists all the SignalR Service under the current subscription.
    '''
    return call_az("az signalr list", locals())


def show(name, resource_group):
    '''
    Get the details of a SignalR Service.
    '''
    return call_az("az signalr show", locals())


def restart(name, resource_group):
    '''
    Restart an existing SignalR Service.
    '''
    return call_az("az signalr restart", locals())


def update(name, resource_group, add=None, allowed_origins=None, default_action=None, enable_message_logs=None, force_string=None, remove=None, service_mode=None, set=None, sku=None, tags=None, unit_count=None):
    '''
    Update an existing SignalR Service.
    '''
    return call_az("az signalr update", locals())




from ...... pyaz_utils import call_az

def add(policy_name, resource_group, type, version, group_name=None, rules=None):
    '''
    Add managed rule set to the WAF policy managed rules. For rule set and rules, please visit: https://docs.microsoft.com/azure/web-application-firewall/ag/application-gateway-crs-rulegroups-rules

    '''
    return call_az("az network application-gateway waf-policy managed-rule rule-set add", locals())


def update(policy_name, resource_group, type, version, add=None, force_string=None, group_name=None, remove=None, rules=None, set=None):
    '''
    Manage rules of a WAF policy. If --group-name and --rules are provided, override existing rules. If --group-name is provided, clear all rules under a certain rule group. If neither of them are provided, update rule set and clear all rules under itself. For rule set and rules, please visit: https://docs.microsoft.com/azure/web-application-firewall/ag/application-gateway-crs-rulegroups-rules

    '''
    return call_az("az network application-gateway waf-policy managed-rule rule-set update", locals())


def remove(policy_name, resource_group, type, version, group_name=None):
    '''
    Remove a managed rule set by rule set group name if rule_group_name is specified. Otherwise, remove all rule set.

    '''
    return call_az("az network application-gateway waf-policy managed-rule rule-set remove", locals())


def list(policy_name, resource_group):
    '''
    List all managed rule set.
    '''
    return call_az("az network application-gateway waf-policy managed-rule rule-set list", locals())




from ... pyaz_utils import call_az

def show(instance_id=None, location=None):
    '''
    Show the details of a database account that can be restored.
    '''
    return call_az("az cosmosdb restorable-database-account show", locals())


def list(account_name=None, location=None):
    '''
    List all the database accounts that can be restored.
    '''
    return call_az("az cosmosdb restorable-database-account list", locals())




from ... pyaz_utils import call_az

def show(origin_group_name, origin_name, profile_name, resource_group):
    return call_az("az afd origin show", locals())


def list(origin_group_name, profile_name, resource_group):
    return call_az("az afd origin list", locals())


def create(enabled_state, host_name, origin_group_name, origin_name, profile_name, resource_group, enable_private_link=None, http_port=None, https_port=None, origin_host_header=None, priority=None, private_link_location=None, private_link_request_message=None, private_link_resource=None, private_link_sub_resource_type=None, weight=None):
    '''
    Create an AFD origin.
    '''
    return call_az("az afd origin create", locals())


def update(origin_group_name, origin_name, profile_name, resource_group, enable_private_link=None, enabled_state=None, host_name=None, http_port=None, https_port=None, origin_host_header=None, priority=None, private_link_location=None, private_link_request_message=None, private_link_resource=None, private_link_sub_resource_type=None, weight=None):
    '''
    Update the settings of the specified AFD origin.
    '''
    return call_az("az afd origin update", locals())


def delete(origin_group_name, origin_name, profile_name, resource_group, yes=None):
    return call_az("az afd origin delete", locals())




from ... pyaz_utils import call_az

def format(secrets, certificate_store=None, keyvault=None, resource_group=None):
    '''
    Transform secrets into a form that can be used by VMs and VMSSes.
    '''
    return call_az("az vm secret format", locals())


def add(certificate, keyvault, name, resource_group, certificate_store=None):
    '''
    Add a secret to a VM.
    '''
    return call_az("az vm secret add", locals())


def list(name, resource_group):
    '''
    List secrets on a VM.
    '''
    return call_az("az vm secret list", locals())


def remove(keyvault, name, resource_group, certificate=None):
    '''
    Remove a secret from a VM.
    '''
    return call_az("az vm secret remove", locals())




from ... pyaz_utils import call_az

def build(builder, image, registry, agent_pool=None, auth_mode=None, no_format=None, no_logs=None, no_wait=None, pack_image_tag=None, platform=None, pull=None, resource_group=None, timeout=None):
    '''
    Queues a quick build task that builds an app and pushes it into an Azure Container Registry.
    '''
    return call_az("az acr pack build", locals())




from .. pyaz_utils import call_az
from . import cluster, experiment, file_server, job, workspace


def list_usages(location):
    '''
    Gets the current usage information as well as limits for Batch AI resources for given location.
    '''
    return call_az("az batchai list-usages", locals())




from ... pyaz_utils import call_az

def list(management_group_id, filter=None):
    '''
    List deployments at management group.
    '''
    return call_az("az deployment mg list", locals())


def show(management_group_id, name):
    '''
    Show a deployment at management group.
    '''
    return call_az("az deployment mg show", locals())


def delete(management_group_id, name, no_wait=None):
    '''
    Delete a deployment at management group.
    '''
    return call_az("az deployment mg delete", locals())


def validate(location, management_group_id, handle_extended_json_format=None, name=None, no_prompt=None, parameters=None, query_string=None, template_file=None, template_spec=None, template_uri=None):
    '''
    Validate whether a template is valid at management group.
    '''
    return call_az("az deployment mg validate", locals())


def create(location, management_group_id, confirm_with_what_if=None, handle_extended_json_format=None, name=None, no_prompt=None, no_wait=None, parameters=None, proceed_if_no_change=None, query_string=None, template_file=None, template_spec=None, template_uri=None, what_if=None, what_if_exclude_change_types=None, what_if_result_format=None):
    '''
    Start a deployment at management group.
    '''
    return call_az("az deployment mg create", locals())


def what_if(location, management_group_id, exclude_change_types=None, name=None, no_pretty_print=None, no_prompt=None, parameters=None, query_string=None, result_format=None, template_file=None, template_spec=None, template_uri=None):
    '''
    Execute a deployment What-If operation at management group scope.
    '''
    return call_az("az deployment mg what-if", locals())


def export(management_group_id, name):
    '''
    Export the template used for a deployment.
    '''
    return call_az("az deployment mg export", locals())


def wait(management_group_id, name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a deployment condition is met.
    '''
    return call_az("az deployment mg wait", locals())


def cancel(management_group_id, name):
    '''
    Cancel a deployment at management group.
    '''
    return call_az("az deployment mg cancel", locals())




from .. pyaz_utils import call_az
from . import registration


def list(namespace=None):
    '''
    List preview features.
    '''
    return call_az("az feature list", locals())


def show(name, namespace):
    return call_az("az feature show", locals())


def register(name, namespace):
    '''
    register a preview feature.
    '''
    return call_az("az feature register", locals())


def unregister(name, namespace):
    '''
    unregister a preview feature.
    '''
    return call_az("az feature unregister", locals())




from . pyaz_utils import call_az
from . import account, acr, acs, aks, apim, appconfig, aro, bicep, bot, cache, cdn, cloud, config, container, cosmosdb, demo, deployment, deployment_scripts, disk, disk_access, disk_encryption_set, dms, extension, feature, group, hdinsight, identity, image, keyvault, local_context, lock, logicapp, managedapp, network, openshift, ppg, provider, redis, resource, sig, signalr, snapshot, sql, sshkey, staticwebapp, storage, tag, term, ts, webapp


def configure(defaults=None, list_defaults=None, scope=None):
    '''
    Manage Azure CLI configuration. This command is interactive.
    '''
    return call_az("az configure", locals())


def feedback():
    '''
    Send feedback to the Azure CLI Team.
    '''
    return call_az("az feedback", locals())


def find():
    '''
    I'm an AI robot, my advice is based on our Azure documentation as well as the usage patterns of Azure CLI and Azure ARM users. Using me improves Azure products and documentation.
    '''
    return call_az("az find", locals())


def interactive(style=None, update=None):
    '''
    Start interactive mode. Installs the Interactive extension if not installed already.
    '''
    return call_az("az interactive", locals())


def login(allow_no_subscriptions=None, federated_token=None, password=None, scope=None, service_principal=None, tenant=None, use_cert_sn_issuer=None, use_device_code=None, username=None):
    '''
    Log in to Azure.
    '''
    return call_az("az login", locals())


def logout(username=None):
    return call_az("az logout", locals())


def self_test():
    '''
    Runs a self-test of the CLI.
    '''
    return call_az("az self-test", locals())


def rest(url, body=None, headers=None, method=None, output_file=None, resource=None, skip_authorization_header=None, uri_parameters=None):
    '''
    Invoke a custom request.
    '''
    return call_az("az rest", locals())


def version():
    '''
    Show the versions of Azure CLI modules and extensions in JSON format by default or format configured by --output
    '''
    return call_az("az version", locals())


def upgrade(all=None, yes=None):
    '''
    Upgrade Azure CLI and extensions
    '''
    return call_az("az upgrade", locals())




from .... pyaz_utils import call_az

def list(api_id, resource_group, service_name):
    '''
    Lists all releases of an API.
    '''
    return call_az("az apim api release list", locals())


def show(api_id, release_id, resource_group, service_name):
    '''
    Returns the details of an API release.
    '''
    return call_az("az apim api release show", locals())


def create(api_id, api_revision, resource_group, service_name, if_match=None, notes=None, release_id=None):
    '''
    Creates a new Release for the API.
    '''
    return call_az("az apim api release create", locals())


def update(api_id, release_id, resource_group, service_name, add=None, api_id1=None, force_string=None, if_match=None, notes=None, remove=None, set=None):
    '''
    Updates the details of the release of the API specified by its identifier.
    '''
    return call_az("az apim api release update", locals())


def delete(api_id, release_id, resource_group, service_name, if_match=None):
    '''
    Deletes the specified release in the API.
    '''
    return call_az("az apim api release delete", locals())




from ... pyaz_utils import call_az
from . import immutability_policy, lease, legal_hold, metadata, policy


def list(account_key=None, account_name=None, auth_mode=None, connection_string=None, include_deleted=None, include_metadata=None, marker=None, num_results=None, prefix=None, sas_token=None, show_next_marker=None, timeout=None):
    '''
    List containers in a storage account.
    '''
    return call_az("az storage container list", locals())


def delete(name, account_key=None, account_name=None, auth_mode=None, bypass_immutability_policy=None, connection_string=None, fail_not_exist=None, if_modified_since=None, if_unmodified_since=None, lease_id=None, sas_token=None, timeout=None):
    '''
    Marks the specified container for deletion.
    '''
    return call_az("az storage container delete", locals())


def show(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None, timeout=None):
    return call_az("az storage container show", locals())


def create(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, default_encryption_scope=None, fail_on_exist=None, metadata=None, prevent_encryption_scope_override=None, public_access=None, resource_group=None, sas_token=None, timeout=None):
    '''
    Create a container in a storage account.
    '''
    return call_az("az storage container create", locals())


def generate_sas(name, account_key=None, account_name=None, as_user=None, auth_mode=None, cache_control=None, connection_string=None, content_disposition=None, content_encoding=None, content_language=None, content_type=None, expiry=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None):
    '''
    Generate a SAS token for a storage container.
    '''
    return call_az("az storage container generate-sas", locals())


def exists(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Check for the existence of a storage container.
    '''
    return call_az("az storage container exists", locals())


def set_permission(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_modified_since=None, if_unmodified_since=None, lease_id=None, public_access=None, sas_token=None, timeout=None):
    return call_az("az storage container set-permission", locals())


def show_permission(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None, timeout=None):
    return call_az("az storage container show-permission", locals())


def restore(deleted_version, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Restore soft-deleted container.
    '''
    return call_az("az storage container restore", locals())




from .... pyaz_utils import call_az

def create(role, workspace_name, assignee=None, assignee_object_id=None, assignee_principal_type=None, assignment_id=None, item=None, item_type=None, scope=None):
    '''
    Create a role assignment.
    '''
    return call_az("az synapse role assignment create", locals())


def list(workspace_name, assignee=None, assignee_object_id=None, item=None, item_type=None, role=None, scope=None):
    '''
    List role assignments.
    '''
    return call_az("az synapse role assignment list", locals())


def show(id, workspace_name):
    '''
    Get a role assignment by id.
    '''
    return call_az("az synapse role assignment show", locals())


def delete(workspace_name, assignee=None, assignee_object_id=None, ids=None, item=None, item_type=None, role=None, scope=None, yes=None):
    '''
    Delete role assignments of workspace.
    '''
    return call_az("az synapse role assignment delete", locals())




from ... pyaz_utils import call_az

def create(lock_type, name, resource_group, notes=None):
    '''
    Create a resource group lock.
    '''
    return call_az("az group lock create", locals())


def delete(ids=None, name=None, resource_group=None):
    '''
    Delete a resource group lock.
    '''
    return call_az("az group lock delete", locals())


def list(filter_string=None, resource_group=None):
    '''
    List lock information in the resource-group.
    '''
    return call_az("az group lock list", locals())


def show(ids=None, name=None, resource_group=None):
    '''
    Show the details of a resource group lock
    '''
    return call_az("az group lock show", locals())


def update(ids=None, lock_type=None, name=None, notes=None, resource_group=None):
    '''
    Update a resource group lock.
    '''
    return call_az("az group lock update", locals())




from .... pyaz_utils import call_az

def show(name, resource_group):
    '''
    Gets backup related properties of the Recovery Services vault.
    '''
    return call_az("az backup vault backup-properties show", locals())


def set(name, resource_group, backup_storage_redundancy=None, cross_region_restore_flag=None, soft_delete_feature_state=None):
    '''
    Sets backup related properties of the Recovery Services vault.
    '''
    return call_az("az backup vault backup-properties set", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, add_disabled=None, calling_web_hook=None, enable_calling=None):
    '''
    Create the Microsoft Teams Channel on a bot.
    '''
    return call_az("az bot msteams create", locals())


def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Microsoft Teams Channel on a bot
    '''
    return call_az("az bot msteams show", locals())


def delete(name, resource_group):
    '''
    Delete the Microsoft Teams Channel on a bot
    '''
    return call_az("az bot msteams delete", locals())




from .. pyaz_utils import call_az
from . import credential, feature, identity, kv, revision


def create(location, name, resource_group, assign_identity=None, disable_local_auth=None, enable_public_network=None, sku=None, tags=None):
    '''
    Create an App Configuration.
    '''
    return call_az("az appconfig create", locals())


def delete(name, resource_group=None, yes=None):
    '''
    Delete an App Configuration.
    '''
    return call_az("az appconfig delete", locals())


def update(name, disable_local_auth=None, enable_public_network=None, encryption_key_name=None, encryption_key_vault=None, encryption_key_version=None, identity_client_id=None, resource_group=None, sku=None, tags=None):
    '''
    Update an App Configuration.
    '''
    return call_az("az appconfig update", locals())


def list(resource_group=None):
    '''
    Lists all App Configurations under the current subscription.
    '''
    return call_az("az appconfig list", locals())


def show(name, resource_group=None):
    '''
    Show properties of an App Configuration.
    '''
    return call_az("az appconfig show", locals())




from ... pyaz_utils import call_az

def list(lab_name, resource_group, expand=None, filter=None, orderby=None, top=None):
    return call_az("az lab artifact-source list", locals())


def show(lab_name, name, resource_group, expand=None):
    return call_az("az lab artifact-source show", locals())




from ... pyaz_utils import call_az

def create(artifact_source_name, location, resource_group, sas_uri, artifact_root=None, tags=None):
    '''
    Creates an artifact source.
    '''
    return call_az("az deploymentmanager artifact-source create", locals())


def delete(artifact_source_name, resource_group, yes=None):
    '''
    Deletes an artifact source.
    '''
    return call_az("az deploymentmanager artifact-source delete", locals())


def show(artifact_source_name, resource_group):
    '''
    Get the details of an artifact source.
    '''
    return call_az("az deploymentmanager artifact-source show", locals())


def list(resource_group):
    '''
    List all artifact sources in a resource group.
    '''
    return call_az("az deploymentmanager artifact-source list", locals())


def update(artifact_source_name, resource_group, add=None, artifact_root=None, force_string=None, remove=None, sas_uri=None, set=None, tags=None):
    '''
    Updates an artifact source.
    '''
    return call_az("az deploymentmanager artifact-source update", locals())




from ... pyaz_utils import call_az

def list(device_name, resource_group):
    '''
    Get all the bandwidth schedules for a Data Box Edge/Data Box Gateway device.
    '''
    return call_az("az databoxedge bandwidth-schedule list", locals())


def show(device_name, name, resource_group):
    '''
    Get the properties of the specified bandwidth schedule.
    '''
    return call_az("az databoxedge bandwidth-schedule show", locals())


def create(days, device_name, name, rate_in_mbps, resource_group, start, stop, no_wait=None):
    '''
    Create a bandwidth schedule.
    '''
    return call_az("az databoxedge bandwidth-schedule create", locals())


def update(days, device_name, name, rate_in_mbps, resource_group, start, stop, add=None, force_string=None, no_wait=None, remove=None, set=None):
    '''
    Update a bandwidth schedule.
    '''
    return call_az("az databoxedge bandwidth-schedule update", locals())


def delete(device_name, name, resource_group, no_wait=None, yes=None):
    '''
    Delete the specified bandwidth schedule.
    '''
    return call_az("az databoxedge bandwidth-schedule delete", locals())


def wait(device_name, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the databoxedge bandwidth-schedule is met.
    '''
    return call_az("az databoxedge bandwidth-schedule wait", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, sku, is_linux=None, location=None, max_burst=None, number_of_workers=None, tags=None, zone_redundant=None):
    '''
    Create an App Service Plan for an Azure Function.
    '''
    return call_az("az functionapp plan create", locals())


def update(name, resource_group, add=None, force_string=None, max_burst=None, number_of_workers=None, remove=None, set=None, sku=None):
    '''
    Update an App Service plan for an Azure Function.
    '''
    return call_az("az functionapp plan update", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete an App Service Plan.
    '''
    return call_az("az functionapp plan delete", locals())


def list(resource_group=None):
    '''
    List App Service Plans.
    '''
    return call_az("az functionapp plan list", locals())


def show(name, resource_group):
    '''
    Get the App Service Plans for a resource group or a set of resource groups.
    '''
    return call_az("az functionapp plan show", locals())




"""
Utility functions for the pyaz generated code to use
"""
import json
import subprocess
from typing import Dict

def call_az(command: str, parameters: Dict) -> object:
    """
    Runs an az command (supplied as a string, and parameters as dictionary) 
    Calls az cli via a subprocess
    Returns the az cli json converted to python object
    
    Example:
    `
    call_az("az group create", locals())
    `
    """
    params = _get_params(parameters)
    commands = command.split()
    commands.extend(params)
    full_command = " ".join(commands)
    print(f"Executing command: {full_command}")
    output = subprocess.run(commands, shell=False, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    stdout = output.stdout.decode("utf-8")
    stderr = output.stderr.decode("utf-8")
    if stdout:
        return json.loads(stdout)
        print(stdout)
    elif stderr:
        raise Exception(stderr)
        print(stderr)  
    

def _get_cli_name(name: str) -> str:
    """
    converts name back to cli format from pythonic version
    - strips trailing underscore from keywords
    - converts remaining underscores to dashes
    - adds leading dashes
    """
    if name[-1] == "_":
        name = name[0:-1]
    name = name.replace("_","-")
    name = f"--{name}"
    return name

def _get_params(locals: Dict) -> str:
    """
    given the built-in locals dictionary returns a formatted string
    with the az cli formatted parameter names and values in a comma-separated list
    """
    #return params
    output = []
    
    # loop through locals and append list of parameters and their values
    # as long as the parameter has a value
    for param in locals:
        if locals[param]:
            
            # if value is a boolean then don't append value, just param, used for flags
            if type(locals[param]) == bool:
                output.append(_get_cli_name(param))
            else:
                output.append(_get_cli_name(param))
                output.append(locals[param])    
    
    return output



from ... pyaz_utils import call_az
from . import repo


def list(name, password=None, repository=None, resource_group=None, suffix=None, username=None):
    '''
    List all helm charts in an Azure Container Registry.
    '''
    return call_az("az acr helm list", locals())


def show(name, password=None, repository=None, resource_group=None, suffix=None, username=None, version=None):
    '''
    Describe a helm chart in an Azure Container Registry.
    '''
    return call_az("az acr helm show", locals())


def delete(name, password=None, prov=None, repository=None, resource_group=None, suffix=None, username=None, version=None, yes=None):
    '''
    Delete a helm chart version in an Azure Container Registry.
    '''
    return call_az("az acr helm delete", locals())


def push(name, force=None, password=None, repository=None, resource_group=None, suffix=None, username=None):
    '''
    Push a helm chart package to an Azure Container Registry.
    '''
    return call_az("az acr helm push", locals())


def install_cli(client_version=None, install_location=None, yes=None):
    '''
    Download and install Helm command-line tool.
    '''
    return call_az("az acr helm install-cli", locals())




from .... pyaz_utils import call_az

def list(group):
    return call_az("az ad group member list", locals())


def add(group, member_id, additional_properties=None):
    return call_az("az ad group member add", locals())


def remove(group, member_id):
    return call_az("az ad group member remove", locals())


def check(group, member_id):
    '''
    Check if a member is in a group.
    '''
    return call_az("az ad group member check", locals())




from .... pyaz_utils import call_az

def start(destination_blob, destination_container, account_key=None, account_name=None, auth_mode=None, connection_string=None, destination_if_match=None, destination_if_modified_since=None, destination_if_none_match=None, destination_if_unmodified_since=None, destination_lease_id=None, destination_tags_condition=None, metadata=None, rehydrate_priority=None, requires_sync=None, sas_token=None, source_account_key=None, source_account_name=None, source_blob=None, source_container=None, source_if_match=None, source_if_modified_since=None, source_if_none_match=None, source_if_unmodified_since=None, source_lease_id=None, source_path=None, source_sas=None, source_share=None, source_snapshot=None, source_tags_condition=None, source_uri=None, tags=None, tier=None, timeout=None):
    '''
    Copy a blob asynchronously. Use `az storage blob show` to check the status of the blobs.
    '''
    return call_az("az storage blob copy start", locals())


def cancel(copy_id, destination_blob, destination_container, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None, timeout=None):
    return call_az("az storage blob copy cancel", locals())


def start_batch(account_key=None, account_name=None, auth_mode=None, connection_string=None, destination_container=None, destination_path=None, dryrun=None, pattern=None, sas_token=None, source_account_key=None, source_account_name=None, source_client=None, source_container=None, source_sas=None, source_share=None, source_uri=None):
    '''
    Copy multiple blobs to a blob container. Use `az storage blob show` to check the status of the blobs.
    '''
    return call_az("az storage blob copy start-batch", locals())




from ... pyaz_utils import call_az

def list(category=None, ids=None, refresh=None, resource_group=None):
    '''
    List Azure Advisor recommendations.
    '''
    return call_az("az advisor recommendation list", locals())


def disable(days=None, ids=None, name=None, resource_group=None):
    '''
    Disable Azure Advisor recommendations.
    '''
    return call_az("az advisor recommendation disable", locals())


def enable(ids=None, name=None, resource_group=None):
    '''
    Enable Azure Advisor recommendations.
    '''
    return call_az("az advisor recommendation enable", locals())




from .. pyaz_utils import call_az
from . import command, nodepool


def browse(name, resource_group, disable_browser=None, listen_address=None, listen_port=None):
    '''
    Show the dashboard for a Kubernetes cluster in a web browser.
    '''
    return call_az("az aks browse", locals())


def create(name, resource_group, aad_admin_group_object_ids=None, aad_client_app_id=None, aad_server_app_id=None, aad_server_app_secret=None, aad_tenant_id=None, aci_subnet_name=None, admin_username=None, aks_custom_headers=None, api_server_authorized_ip_ranges=None, appgw_id=None, appgw_name=None, appgw_subnet_cidr=None, appgw_subnet_id=None, appgw_watch_namespace=None, assign_identity=None, assign_kubelet_identity=None, attach_acr=None, auto_upgrade_channel=None, client_secret=None, cluster_autoscaler_profile=None, disable_local_accounts=None, disable_public_fqdn=None, disable_rbac=None, dns_name_prefix=None, dns_service_ip=None, docker_bridge_address=None, edge_zone=None, enable_aad=None, enable_addons=None, enable_ahub=None, enable_azure_rbac=None, enable_cluster_autoscaler=None, enable_encryption_at_host=None, enable_managed_identity=None, enable_node_public_ip=None, enable_private_cluster=None, enable_rbac=None, enable_secret_rotation=None, enable_sgxquotehelper=None, enable_ultra_ssd=None, fqdn_subdomain=None, generate_ssh_keys=None, kubernetes_version=None, load_balancer_idle_timeout=None, load_balancer_managed_outbound_ip_count=None, load_balancer_outbound_ip_prefixes=None, load_balancer_outbound_ips=None, load_balancer_outbound_ports=None, load_balancer_sku=None, location=None, max_count=None, max_pods=None, min_count=None, network_plugin=None, network_policy=None, no_ssh_key=None, no_wait=None, node_count=None, node_osdisk_diskencryptionset_id=None, node_osdisk_size=None, node_osdisk_type=None, node_public_ip_prefix_id=None, node_vm_size=None, nodepool_labels=None, nodepool_name=None, nodepool_tags=None, os_sku=None, outbound_type=None, pod_cidr=None, ppg=None, private_dns_zone=None, rotation_poll_interval=None, service_cidr=None, service_principal=None, skip_subnet_role_assignment=None, ssh_key_value=None, tags=None, uptime_sla=None, vm_set_type=None, vnet_subnet_id=None, windows_admin_password=None, windows_admin_username=None, workspace_resource_id=None, yes=None, zones=None):
    '''
    Create a new managed Kubernetes cluster.
    '''
    return call_az("az aks create", locals())


def update(name, resource_group, aad_admin_group_object_ids=None, aad_tenant_id=None, aks_custom_headers=None, api_server_authorized_ip_ranges=None, assign_identity=None, attach_acr=None, auto_upgrade_channel=None, cluster_autoscaler_profile=None, detach_acr=None, disable_ahub=None, disable_azure_rbac=None, disable_cluster_autoscaler=None, disable_local_accounts=None, disable_public_fqdn=None, disable_secret_rotation=None, enable_aad=None, enable_ahub=None, enable_azure_rbac=None, enable_cluster_autoscaler=None, enable_local_accounts=None, enable_managed_identity=None, enable_public_fqdn=None, enable_secret_rotation=None, load_balancer_idle_timeout=None, load_balancer_managed_outbound_ip_count=None, load_balancer_outbound_ip_prefixes=None, load_balancer_outbound_ips=None, load_balancer_outbound_ports=None, max_count=None, min_count=None, no_uptime_sla=None, no_wait=None, nodepool_labels=None, rotation_poll_interval=None, tags=None, update_cluster_autoscaler=None, uptime_sla=None, windows_admin_password=None, yes=None):
    '''
    Update a managed Kubernetes cluster.
    '''
    return call_az("az aks update", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a managed Kubernetes cluster.
    '''
    return call_az("az aks delete", locals())


def update_credentials(name, resource_group, aad_client_app_id=None, aad_server_app_id=None, aad_server_app_secret=None, aad_tenant_id=None, client_secret=None, no_wait=None, reset_aad=None, reset_service_principal=None, service_principal=None):
    '''
    Update credentials for a managed Kubernetes cluster, like service principal.
    '''
    return call_az("az aks update-credentials", locals())


def disable_addons(addons, name, resource_group, no_wait=None):
    '''
    Disable Kubernetes addons.
    '''
    return call_az("az aks disable-addons", locals())


def enable_addons(addons, name, resource_group, appgw_id=None, appgw_name=None, appgw_subnet_cidr=None, appgw_subnet_id=None, appgw_watch_namespace=None, enable_secret_rotation=None, enable_sgxquotehelper=None, no_wait=None, rotation_poll_interval=None, subnet_name=None, workspace_resource_id=None):
    '''
    Enable Kubernetes addons.
    '''
    return call_az("az aks enable-addons", locals())


def get_credentials(name, resource_group, admin=None, context=None, file=None, overwrite_existing=None, public_fqdn=None):
    '''
    Get access credentials for a managed Kubernetes cluster.
    '''
    return call_az("az aks get-credentials", locals())


def check_acr(acr, name, resource_group):
    '''
    Validate an ACR is accessible from an AKS cluster.
    '''
    return call_az("az aks check-acr", locals())


def get_upgrades(name, resource_group):
    '''
    Get the upgrade versions available for a managed Kubernetes cluster.
    '''
    return call_az("az aks get-upgrades", locals())


def install_cli(base_src_url=None, client_version=None, install_location=None, kubelogin_base_src_url=None, kubelogin_install_location=None, kubelogin_version=None):
    '''
    Download and install kubectl, the Kubernetes command-line tool. Download and install kubelogin, a client-go credential (exec) plugin implementing azure authentication.
    '''
    return call_az("az aks install-cli", locals())


def list(resource_group=None):
    '''
    List managed Kubernetes clusters.
    '''
    return call_az("az aks list", locals())


def remove_dev_spaces(name, resource_group, yes=None):
    '''
    Remove Azure Dev Spaces from a managed Kubernetes cluster.
    '''
    return call_az("az aks remove-dev-spaces", locals())


def scale(name, node_count, resource_group, no_wait=None, nodepool_name=None):
    '''
    Scale the node pool in a managed Kubernetes cluster.
    '''
    return call_az("az aks scale", locals())


def show(name, resource_group):
    '''
    Show the details for a managed Kubernetes cluster.
    '''
    return call_az("az aks show", locals())


def upgrade(name, resource_group, control_plane_only=None, kubernetes_version=None, no_wait=None, node_image_only=None, yes=None):
    '''
    Upgrade a managed Kubernetes cluster to a newer version.
    '''
    return call_az("az aks upgrade", locals())


def use_dev_spaces(name, resource_group, endpoint=None, space=None, update=None, yes=None):
    '''
    Use Azure Dev Spaces with a managed Kubernetes cluster.
    '''
    return call_az("az aks use-dev-spaces", locals())


def rotate_certs(name, resource_group, no_wait=None, yes=None):
    '''
    Rotate certificates and keys on a managed Kubernetes cluster
    '''
    return call_az("az aks rotate-certs", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for a managed Kubernetes cluster to reach a desired state.
    '''
    return call_az("az aks wait", locals())


def stop(name, resource_group, no_wait=None):
    return call_az("az aks stop", locals())


def start(name, resource_group, no_wait=None):
    return call_az("az aks start", locals())


def get_versions(location):
    '''
    Get the versions available for creating a managed Kubernetes cluster.
    '''
    return call_az("az aks get-versions", locals())




from ... pyaz_utils import call_az

def show(location):
    '''
    Show the Azure CosmosDB location properties in the given location.
    '''
    return call_az("az cosmosdb locations show", locals())


def list():
    '''
    Retrieves the list of cosmosdb locations and their properties.
    '''
    return call_az("az cosmosdb locations list", locals())




from ..... pyaz_utils import call_az

def list(partner_namespace_name, resource_group):
    '''
    List shared access keys of a partner namespace.
    '''
    return call_az("az eventgrid partner namespace key list", locals())


def regenerate(key_name, partner_namespace_name, resource_group):
    '''
    Regenerate a shared access key of a partner namespace.
    '''
    return call_az("az eventgrid partner namespace key regenerate", locals())




from .. pyaz_utils import call_az
from . import param_persist


def set(local=None):
    '''
    Set a configuration.
    '''
    return call_az("az config set", locals())


def get(local=None):
    '''
    Get a configuration.
    '''
    return call_az("az config get", locals())


def unset(local=None):
    '''
    Unset a configuration.
    '''
    return call_az("az config unset", locals())




from .... pyaz_utils import call_az
from . import data_export, linked_service, linked_storage, pack, saved_search, table


def create(resource_group, workspace_name, capacity_reservation_level=None, ingestion_access=None, location=None, no_wait=None, query_access=None, quota=None, retention_time=None, sku=None, tags=None):
    '''
    Create a workspace instance
    '''
    return call_az("az monitor log-analytics workspace create", locals())


def update(resource_group, workspace_name, add=None, capacity_reservation_level=None, force_string=None, ingestion_access=None, query_access=None, quota=None, remove=None, retention_time=None, set=None, tags=None):
    '''
    Update a workspace instance
    '''
    return call_az("az monitor log-analytics workspace update", locals())


def show(resource_group, workspace_name):
    '''
    Show a workspace instance.
    '''
    return call_az("az monitor log-analytics workspace show", locals())


def delete(resource_group, workspace_name, force=None, yes=None):
    '''
    Delete a workspace instance.
    '''
    return call_az("az monitor log-analytics workspace delete", locals())


def list(resource_group=None):
    '''
    Get a list of workspaces under a resource group or a subscription.
    '''
    return call_az("az monitor log-analytics workspace list", locals())


def list_deleted_workspaces(resource_group=None):
    '''
    Get a list of deleted workspaces that can be recovered in a subscription or a resource group.
    '''
    return call_az("az monitor log-analytics workspace list-deleted-workspaces", locals())


def recover(workspace_name, no_wait=None, resource_group=None):
    '''
    Recover a workspace in a soft-delete state within 14 days.
    '''
    return call_az("az monitor log-analytics workspace recover", locals())


def get_schema(resource_group, workspace_name):
    '''
    Get the schema for a given workspace.
    '''
    return call_az("az monitor log-analytics workspace get-schema", locals())


def list_usages(resource_group, workspace_name):
    '''
    Get a list of usage metrics for a workspace.
    '''
    return call_az("az monitor log-analytics workspace list-usages", locals())


def list_management_groups(resource_group, workspace_name):
    '''
    Get a list of management groups connected to a workspace.
    '''
    return call_az("az monitor log-analytics workspace list-management-groups", locals())


def get_shared_keys(resource_group, workspace_name):
    '''
    Get the shared keys for a workspace.
    '''
    return call_az("az monitor log-analytics workspace get-shared-keys", locals())




from .. pyaz_utils import call_az
from . import gallery_application, image_definition, image_version, share


def create(gallery_name, resource_group, description=None, location=None, permissions=None, soft_delete=None, tags=None):
    '''
    Create a shared image gallery.
    '''
    return call_az("az sig create", locals())


def show(gallery_name, resource_group, select=None):
    return call_az("az sig show", locals())


def list(resource_group=None):
    '''
    list share image galleries.
    '''
    return call_az("az sig list", locals())


def delete(gallery_name, resource_group):
    return call_az("az sig delete", locals())


def update(gallery_name, resource_group, add=None, force_string=None, permissions=None, remove=None, select=None, set=None, soft_delete=None):
    '''
    update a share image gallery.
    '''
    return call_az("az sig update", locals())


def list_shared(location, shared_to=None):
    '''
    List all galleries shared directly to your subscription or tenant (preview).
    '''
    return call_az("az sig list-shared", locals())


def show_shared(gallery_unique_name, location):
    '''
    Get a gallery that has been shared directly to your subscription or tenant (preview).
    '''
    return call_az("az sig show-shared", locals())




from ... pyaz_utils import call_az

def show(lab_name, name, resource_group, expand=None):
    return call_az("az lab vm show", locals())


def delete(lab_name, name, resource_group):
    return call_az("az lab vm delete", locals())


def start(lab_name, name, resource_group):
    return call_az("az lab vm start", locals())


def stop(lab_name, name, resource_group):
    return call_az("az lab vm stop", locals())


def apply_artifacts(lab_name, name, resource_group, artifacts=None):
    '''
    Apply artifacts to a virtual machine in Azure DevTest Lab.
    '''
    return call_az("az lab vm apply-artifacts", locals())


def list(lab_name, resource_group, all=None, claimable=None, environment=None, expand=None, filters=None, object_id=None, order_by=None, top=None):
    '''
    List the VMs in an Azure DevTest Lab.
    '''
    return call_az("az lab vm list", locals())


def claim(lab_name=None, name=None, resource_group=None):
    '''
    Claim a virtual machine from the Lab.
    '''
    return call_az("az lab vm claim", locals())


def create(lab_name, name, resource_group, admin_password=None, admin_username=None, allow_claim=None, artifacts=None, authentication_type=None, disk_type=None, expiration_date=None, formula=None, generate_ssh_keys=None, image=None, image_type=None, ip_configuration=None, notes=None, saved_secret=None, size=None, ssh_key=None, subnet=None, tags=None, vnet_name=None):
    '''
    Create a VM in a lab.
    '''
    return call_az("az lab vm create", locals())




from ... pyaz_utils import call_az
from . import output


def show(account_name, name, resource_group):
    '''
    Show the details of a transform.
    '''
    return call_az("az ams transform show", locals())


def list(account_name, resource_group, filter=None, orderby=None):
    '''
    List all the transforms of an Azure Media Services account.
    '''
    return call_az("az ams transform list", locals())


def delete(account_name, name, resource_group):
    '''
    Delete a transform.
    '''
    return call_az("az ams transform delete", locals())


def create(account_name, name, preset, resource_group, audio_analysis_mode=None, audio_language=None, description=None, insights_to_extract=None, on_error=None, relative_priority=None, resolution=None, video_analysis_mode=None):
    '''
    Create a transform.
    '''
    return call_az("az ams transform create", locals())


def update(account_name, name, resource_group, add=None, description=None, force_string=None, remove=None, set=None):
    '''
    Update the details of a transform.
    '''
    return call_az("az ams transform update", locals())




from ..... pyaz_utils import call_az

def show(account_name, name, resource_group):
    '''
    Get the throughput of the MongoDB database under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb mongodb database throughput show", locals())


def update(account_name, name, resource_group, max_throughput=None, throughput=None):
    '''
    Update the throughput of the MongoDB database under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb mongodb database throughput update", locals())


def migrate(account_name, name, resource_group, throughput_type):
    '''
    Migrate the throughput of the MongoDB database between autoscale and manually provisioned.
    '''
    return call_az("az cosmosdb mongodb database throughput migrate", locals())




from ... pyaz_utils import call_az

def start(storage_container_SAS_token, blob_container_name=None, hsm_name=None, id=None, storage_account_name=None, storage_resource_uri=None):
    '''
    Begin a full backup of the HSM.
    '''
    return call_az("az keyvault backup start", locals())




from .... pyaz_utils import call_az

def set(account_key=None, account_name=None, acl=None, auth_mode=None, connection_string=None, group=None, owner=None, permissions=None, sas_token=None):
    '''
    Set the access control properties of a path(directory or file) in Azure Data Lake Storage Gen2 account.
    '''
    return call_az("az storage fs access set", locals())


def show(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None):
    '''
    Show the access control properties of a path (directory or file) in Azure Data Lake Storage Gen2 account.
    '''
    return call_az("az storage fs access show", locals())


def set_recursive(acl, account_key=None, account_name=None, auth_mode=None, batch_size=None, connection_string=None, continuation=None, continue_on_failure=None, max_batches=None, sas_token=None, timeout=None):
    '''
    Set the Access Control on a path and sub-paths in Azure Data Lake Storage Gen2 account.
    '''
    return call_az("az storage fs access set-recursive", locals())


def update_recursive(acl, account_key=None, account_name=None, auth_mode=None, batch_size=None, connection_string=None, continuation=None, continue_on_failure=None, max_batches=None, sas_token=None, timeout=None):
    '''
    Modify the Access Control on a path and sub-paths in Azure Data Lake Storage Gen2 account.
    '''
    return call_az("az storage fs access update-recursive", locals())


def remove_recursive(acl, account_key=None, account_name=None, auth_mode=None, batch_size=None, connection_string=None, continuation=None, continue_on_failure=None, max_batches=None, sas_token=None, timeout=None):
    '''
    Remove the Access Control on a path and sub-paths in Azure Data Lake Storage Gen2 account.
    '''
    return call_az("az storage fs access remove-recursive", locals())




from .... pyaz_utils import call_az

def setup(admin_password, admin_user, database_name, repo, resource_group, server_name, sql_file, action_name=None, allow_push=None, branch=None):
    '''
    Create github action workflow file for MySQL server.
    '''
    return call_az("az mysql flexible-server deploy setup", locals())


def run(action_name, branch):
    '''
    Run an existing workflow in your github repository
    '''
    return call_az("az mysql flexible-server deploy run", locals())




from .... pyaz_utils import call_az

def create(name, partner_server, resource_group, server, auto_pause_delay=None, backup_storage_redundancy=None, capacity=None, compute_model=None, elastic_pool=None, family=None, license_type=None, min_capacity=None, no_wait=None, partner_database=None, partner_resource_group=None, read_replicas=None, read_scale=None, secondary_type=None, service_objective=None, tags=None, zone_redundant=None):
    '''
    Create a database as a readable secondary replica of an existing database.
    '''
    return call_az("az sql db replica create", locals())


def list_links(name, resource_group, server):
    '''
    List the replicas of a database and their replication status.
    '''
    return call_az("az sql db replica list-links", locals())


def delete_link(name, partner_server, resource_group, server, partner_resource_group=None, yes=None):
    '''
    Permanently stop data replication between two database replicas.
    '''
    return call_az("az sql db replica delete-link", locals())


def set_primary(name, resource_group, server, allow_data_loss=None):
    '''
    Set the primary replica database by failing over from the current primary replica database.
    '''
    return call_az("az sql db replica set-primary", locals())




from .... pyaz_utils import call_az

def list(cluster, resource_group, workspace):
    '''
    List remote login information for cluster's nodes.
    '''
    return call_az("az batchai cluster node list", locals())


def exec(cluster, resource_group, workspace, address=None, exec=None, node_id=None, password=None, ssh_private_key=None):
    '''
    Executes a command line on a cluster's node with optional ports forwarding.
    '''
    return call_az("az batchai cluster node exec", locals())




from ... pyaz_utils import call_az
from . import collection, database, restorable_collection, restorable_database, restorable_resource


def retrieve_latest_backup_time(account_name, collection_name, database_name, location, resource_group):
    '''
    Retrieves latest restorable timestamp for the given mongodb collection in given region.
    '''
    return call_az("az cosmosdb mongodb retrieve-latest-backup-time", locals())




from ... pyaz_utils import call_az
from . import identity, non_compliance_message


def create(assign_identity=None, description=None, display_name=None, enforcement_mode=None, identity_scope=None, location=None, mi_system_assigned=None, mi_user_assigned=None, name=None, not_scopes=None, params=None, policy=None, policy_set_definition=None, resource_group=None, role=None, scope=None, sku=None):
    '''
    Create a resource policy assignment.
    '''
    return call_az("az policy assignment create", locals())


def delete(name, resource_group=None, scope=None):
    '''
    Delete a resource policy assignment.
    '''
    return call_az("az policy assignment delete", locals())


def list(disable_scope_strict_match=None, resource_group=None, scope=None):
    '''
    List resource policy assignments.
    '''
    return call_az("az policy assignment list", locals())


def show(name, resource_group=None, scope=None):
    '''
    Show a resource policy assignment.
    '''
    return call_az("az policy assignment show", locals())


def update(description=None, display_name=None, enforcement_mode=None, name=None, not_scopes=None, params=None, resource_group=None, scope=None, sku=None):
    '''
    Update a resource policy assignment.
    '''
    return call_az("az policy assignment update", locals())




from .... pyaz_utils import call_az

def grant(api, id, consent_type=None, expires=None, principal_id=None, scope=None):
    '''
    Grant the app an API Delegated permissions
    '''
    return call_az("az ad app permission grant", locals())


def list(id):
    '''
    List API permissions the application has requested
    '''
    return call_az("az ad app permission list", locals())


def add(api, api_permissions, id):
    '''
    Add an API permission
    '''
    return call_az("az ad app permission add", locals())


def delete(api, id, api_permissions=None):
    '''
    Remove an API permission
    '''
    return call_az("az ad app permission delete", locals())


def list_grants(filter=None, id=None, show_resource_name=None):
    '''
    List Oauth2 permission grants
    '''
    return call_az("az ad app permission list-grants", locals())


def admin_consent(id):
    '''
    Grant Application & Delegated permissions through admin-consent.
    '''
    return call_az("az ad app permission admin-consent", locals())




from .... pyaz_utils import call_az

def show(name, resource_group, deployment_id=None, slot=None):
    '''
    Show deployment logs of the latest deployment, or a specific deployment if deployment-id is specified.
    '''
    return call_az("az webapp log deployment show", locals())


def list(name, resource_group, slot=None):
    '''
    List deployments associated with web app
    '''
    return call_az("az webapp log deployment list", locals())




from ... pyaz_utils import call_az

def add(methods, origins, services, account_key=None, account_name=None, allowed_headers=None, connection_string=None, exposed_headers=None, max_age=None, sas_token=None, timeout=None):
    '''
    Add a CORS rule to a storage account.
    '''
    return call_az("az storage cors add", locals())


def clear(services, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Remove all CORS rules from a storage account.
    '''
    return call_az("az storage cors clear", locals())


def list(account_key=None, account_name=None, connection_string=None, sas_token=None, services=None, timeout=None):
    '''
    List all CORS rules for a storage account.
    '''
    return call_az("az storage cors list", locals())




from .... pyaz_utils import call_az
from . import custom_rule, managed_rule_set, rate_limit_rule


def show(name, resource_group):
    '''
    Show details of a CDN WAF policy.
    '''
    return call_az("az cdn waf policy show", locals())


def list(resource_group):
    '''
    List CDN WAF policies.
    '''
    return call_az("az cdn waf policy list", locals())


def set(name, resource_group, block_response_body=None, block_response_status_code=None, disabled=None, mode=None, redirect_url=None, sku=None, tags=None):
    '''
    Create a new CDN WAF policy.
    '''
    return call_az("az cdn waf policy set", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a CDN WAF policy.
    '''
    return call_az("az cdn waf policy delete", locals())




from ... pyaz_utils import call_az
from . import aad, ipsec_policy, nat_rule, packet_capture, revoked_cert, root_cert, vpn_client


def create(name, public_ip_addresses, resource_group, vnet, aad_audience=None, aad_issuer=None, aad_tenant=None, address_prefixes=None, asn=None, bgp_peering_address=None, client_protocol=None, custom_routes=None, edge_zone=None, gateway_default_site=None, gateway_type=None, location=None, nat_rule=None, no_wait=None, peer_weight=None, radius_secret=None, radius_server=None, root_cert_data=None, root_cert_name=None, sku=None, tags=None, vpn_auth_type=None, vpn_gateway_generation=None, vpn_type=None):
    '''
    Create a virtual network gateway.
    '''
    return call_az("az network vnet-gateway create", locals())


def update(name, resource_group, aad_audience=None, aad_issuer=None, aad_tenant=None, add=None, address_prefixes=None, asn=None, bgp_peering_address=None, client_protocol=None, custom_routes=None, enable_bgp=None, force_string=None, gateway_default_site=None, gateway_type=None, no_wait=None, peer_weight=None, public_ip_addresses=None, radius_secret=None, radius_server=None, remove=None, root_cert_data=None, root_cert_name=None, set=None, sku=None, tags=None, vnet=None, vpn_auth_type=None, vpn_type=None):
    '''
    Update a virtual network gateway.
    '''
    return call_az("az network vnet-gateway update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the virtual network gateway is met.
    '''
    return call_az("az network vnet-gateway wait", locals())


def delete(name, resource_group, no_wait=None):
    '''
    Delete a virtual network gateway.
    '''
    return call_az("az network vnet-gateway delete", locals())


def show(name, resource_group):
    '''
    Get the details of a virtual network gateway.
    '''
    return call_az("az network vnet-gateway show", locals())


def list(resource_group):
    '''
    List virtual network gateways.
    '''
    return call_az("az network vnet-gateway list", locals())


def reset(name, resource_group, gateway_vip=None):
    '''
    Reset a virtual network gateway.
    '''
    return call_az("az network vnet-gateway reset", locals())


def list_bgp_peer_status(name, resource_group, peer=None):
    '''
    Retrieve the status of BGP peers.
    '''
    return call_az("az network vnet-gateway list-bgp-peer-status", locals())


def list_advertised_routes(name, peer, resource_group):
    '''
    List the routes of a virtual network gateway advertised to the specified peer.
    '''
    return call_az("az network vnet-gateway list-advertised-routes", locals())


def list_learned_routes(name, resource_group):
    '''
    This operation retrieves a list of routes the virtual network gateway has learned, including routes learned from BGP peers.
    '''
    return call_az("az network vnet-gateway list-learned-routes", locals())


def show_supported_devices(name, resource_group):
    '''
    Get a xml format representation for supported vpn devices.
    '''
    return call_az("az network vnet-gateway show-supported-devices", locals())


def disconnect_vpn_connections(name, resource_group, vpn_connections, no_wait=None):
    '''
    Disconnect vpn connections of virtual network gateway.
    '''
    return call_az("az network vnet-gateway disconnect-vpn-connections", locals())




from ... pyaz_utils import call_az

def show(pe_name, workspace_name):
    '''
    Get a synapse managed private endpoints.
    '''
    return call_az("az synapse managed-private-endpoints show", locals())


def create(group_Id, pe_name, resource_id, workspace_name):
    '''
    Create a synapse managed private endpoints.
    '''
    return call_az("az synapse managed-private-endpoints create", locals())


def list(workspace_name):
    '''
    List synapse managed private endpoints in a workspace.
    '''
    return call_az("az synapse managed-private-endpoints list", locals())


def delete(pe_name, workspace_name, yes=None):
    '''
    delete synapse managed private endpoints in a workspace.
    '''
    return call_az("az synapse managed-private-endpoints delete", locals())




from ... pyaz_utils import call_az

def show(container_name, item_name, resource_group, restore_mode, vault_name, backup_management_type=None, filepath=None, from_full_rp_name=None, log_point_in_time=None, rp_name=None, target_container_name=None, target_item_name=None, target_resource_group=None, target_server_name=None, target_server_type=None, target_vault_name=None, workload_type=None):
    '''
    Construct the recovery configuration of an Azure workload backed up item.
    '''
    return call_az("az backup recoveryconfig show", locals())




from ... pyaz_utils import call_az

def show(resource_group, service_name):
    return call_az("az search admin-key show", locals())


def renew(key_kind, resource_group, service_name):
    return call_az("az search admin-key renew", locals())




from ..... pyaz_utils import call_az

def list(issuer_name, vault_name):
    return call_az("az keyvault certificate issuer admin list", locals())


def add(email, issuer_name, vault_name, first_name=None, last_name=None, phone=None):
    return call_az("az keyvault certificate issuer admin add", locals())


def delete(email, issuer_name, vault_name):
    return call_az("az keyvault certificate issuer admin delete", locals())




from .... pyaz_utils import call_az

def list(name, resource_group, slot=None):
    '''
    Show settings for a function app.
    '''
    return call_az("az functionapp config appsettings list", locals())


def set(name, resource_group, settings=None, slot=None, slot_settings=None):
    '''
    Update a function app's settings.
    '''
    return call_az("az functionapp config appsettings set", locals())


def delete(name, resource_group, setting_names, slot=None):
    '''
    Delete a function app's settings.
    '''
    return call_az("az functionapp config appsettings delete", locals())




from ... pyaz_utils import call_az
from . import metadata, policy


def create(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, fail_on_exist=None, metadata=None, sas_token=None, timeout=None):
    return call_az("az storage queue create", locals())


def delete(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, fail_not_exist=None, sas_token=None, timeout=None):
    return call_az("az storage queue delete", locals())


def generate_sas(name, account_key=None, account_name=None, connection_string=None, expiry=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None):
    return call_az("az storage queue generate-sas", locals())


def stats(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage queue stats", locals())


def exists(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage queue exists", locals())


def list(account_key=None, account_name=None, auth_mode=None, connection_string=None, include_metadata=None, marker=None, num_results=None, prefix=None, sas_token=None, show_next_marker=None, timeout=None):
    '''
    List queues in a storage account.
    '''
    return call_az("az storage queue list", locals())




from ... pyaz_utils import call_az
from . import peering, subnet


def delete(name, resource_group):
    '''
    Delete a virtual network.
    '''
    return call_az("az network vnet delete", locals())


def list(resource_group=None):
    '''
    List virtual networks.
    '''
    return call_az("az network vnet list", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a virtual network.
    '''
    return call_az("az network vnet show", locals())


def check_ip_address(ip_address, name, resource_group):
    '''
    Check if a private IP address is available for use within a virtual network.
    '''
    return call_az("az network vnet check-ip-address", locals())


def create(name, resource_group, address_prefixes=None, bgp_community=None, ddos_protection=None, ddos_protection_plan=None, dns_servers=None, edge_zone=None, enable_encryption=None, encryption_enforcement_policy=None, flowtimeout=None, location=None, network_security_group=None, subnet_name=None, subnet_prefixes=None, tags=None, vm_protection=None):
    '''
    Create a virtual network.
    '''
    return call_az("az network vnet create", locals())


def update(name, resource_group, add=None, address_prefixes=None, bgp_community=None, ddos_protection=None, ddos_protection_plan=None, dns_servers=None, enable_encryption=None, encryption_enforcement_policy=None, flowtimeout=None, force_string=None, remove=None, set=None, vm_protection=None):
    '''
    Update a virtual network.
    '''
    return call_az("az network vnet update", locals())


def list_endpoint_services(location):
    '''
    List which services support VNET service tunneling in a given region.
    '''
    return call_az("az network vnet list-endpoint-services", locals())


def list_available_ips(name, resource_group):
    '''
    List some available ips in the vnet.
    '''
    return call_az("az network vnet list-available-ips", locals())




from ..... pyaz_utils import call_az

def add(connection_monitor, endpoint_dest_name, endpoint_source_name, location, name, test_config_name, disable=None, endpoint_dest_address=None, endpoint_dest_resource_id=None, endpoint_source_address=None, endpoint_source_resource_id=None, frequency=None, http_method=None, http_path=None, http_port=None, http_valid_status_codes=None, https_prefer=None, icmp_disable_trace_route=None, preferred_ip_version=None, protocol=None, tcp_disable_trace_route=None, tcp_port=None, threshold_failed_percent=None, threshold_round_trip_time=None):
    '''
    Add a test group along with new-added/existing endpoint and test configuration to a connection monitor
    '''
    return call_az("az network watcher connection-monitor test-group add", locals())


def remove(connection_monitor, location, name):
    '''
    Remove test group from a connection monitor
    '''
    return call_az("az network watcher connection-monitor test-group remove", locals())


def show(connection_monitor, location, name):
    '''
    Show a test group of a connection monitor
    '''
    return call_az("az network watcher connection-monitor test-group show", locals())


def list(connection_monitor, location):
    '''
    List all test groups of a connection monitor
    '''
    return call_az("az network watcher connection-monitor test-group list", locals())




from ... pyaz_utils import call_az

def add(gallery_name, resource_group, no_wait=None, op_type=None, subscription_ids=None, tenant_ids=None):
    '''
    Share gallery with subscriptions and tenants
    '''
    return call_az("az sig share add", locals())


def remove(gallery_name, resource_group, no_wait=None, op_type=None, subscription_ids=None, tenant_ids=None):
    '''
    stop sharing gallery with a subscription or tenant
    '''
    return call_az("az sig share remove", locals())


def reset(gallery_name, resource_group, no_wait=None):
    '''
    disable gallery from being shared with subscription or tenant
    '''
    return call_az("az sig share reset", locals())


def wait(gallery_name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a shared gallery is met.
    '''
    return call_az("az sig share wait", locals())




from ... pyaz_utils import call_az

def list(all=None, auth_mode=None, connection_string=None, datetime=None, endpoint=None, fields=None, key=None, label=None, name=None, top=None):
    '''
    Lists revision history of key-values.
    '''
    return call_az("az appconfig revision list", locals())




from .... pyaz_utils import call_az

def create(kid, name, resource_group):
    '''
    Create server key.
    '''
    return call_az("az mysql server key create", locals())


def delete(kid, name, resource_group, yes=None):
    '''
    Delete server key.
    '''
    return call_az("az mysql server key delete", locals())


def show(kid, name, resource_group):
    '''
    Show server key.
    '''
    return call_az("az mysql server key show", locals())


def list(name, resource_group):
    return call_az("az mysql server key list", locals())




from .... pyaz_utils import call_az

def create(application, cluster_name, metric_name, name, resource_group, default_load=None, primary_default_load=None, secondary_default_load=None, weight=None):
    '''
    Create a new managed service load metric on an Azure Service Fabric managed cluster.
    '''
    return call_az("az sf managed-service load-metrics create", locals())


def update(application, cluster_name, metric_name, name, resource_group, default_load=None, primary_default_load=None, secondary_default_load=None, weight=None):
    '''
    Update a managed service.
    '''
    return call_az("az sf managed-service load-metrics update", locals())


def delete(application, cluster_name, metric_name, name, resource_group):
    '''
    Delete a managed service.
    '''
    return call_az("az sf managed-service load-metrics delete", locals())




from .... pyaz_utils import call_az

def list(name, resource_group, slot=None):
    '''
    List the restorable snapshots for a web app.
    '''
    return call_az("az webapp config snapshot list", locals())


def restore(name, resource_group, time, restore_content_only=None, slot=None, source_name=None, source_resource_group=None, source_slot=None):
    '''
    Restore a web app snapshot.
    '''
    return call_az("az webapp config snapshot restore", locals())




from .... pyaz_utils import call_az

def approve(account_name, pool_name, resource_group, volume_name, remote_volume_resource_id=None):
    '''
    Authorize a volume as a replication destination for a specified source.
    '''
    return call_az("az netappfiles volume replication approve", locals())


def suspend(account_name, pool_name, resource_group, volume_name, force=None):
    '''
    Suspend/break a volume replication for the specified destination volume. The replication process is suspended until resumed or deleted.
    '''
    return call_az("az netappfiles volume replication suspend", locals())


def resume(account_name, pool_name, resource_group, volume_name):
    '''
    Resync a volume replication for the specified destination volume. The replication process is resumed from source to destination.
    '''
    return call_az("az netappfiles volume replication resume", locals())


def remove(account_name, pool_name, resource_group, volume_name):
    '''
    Delete a volume replication for the specified destination volume. The data replication objects of source and destination volumes will be removed.
    '''
    return call_az("az netappfiles volume replication remove", locals())


def status(account_name, pool_name, resource_group, volume_name):
    '''
    Get the replication status for the specified replication volume.
    '''
    return call_az("az netappfiles volume replication status", locals())


def re_initialize(account_name, pool_name, resource_group, volume_name):
    '''
    Re-initialise a volume replication for the specified destination volume. The replication process is resumed from source to destination.
    '''
    return call_az("az netappfiles volume replication re-initialize", locals())




from ... pyaz_utils import call_az

def list(top=None):
    '''
    List policy metadata resources.
    '''
    return call_az("az policy metadata list", locals())


def show(name):
    '''
    Get a single policy metadata resource.
    '''
    return call_az("az policy metadata show", locals())




from ... pyaz_utils import call_az

def list(registry, resource_group=None):
    '''
    List all of the webhooks for an Azure Container Registry.
    '''
    return call_az("az acr webhook list", locals())


def create(actions, name, registry, uri, headers=None, location=None, resource_group=None, scope=None, status=None, tags=None):
    '''
    Create a webhook for an Azure Container Registry.
    '''
    return call_az("az acr webhook create", locals())


def delete(name, registry, resource_group=None):
    '''
    Delete a webhook from an Azure Container Registry.
    '''
    return call_az("az acr webhook delete", locals())


def show(name, registry, resource_group=None):
    '''
    Get the details of a webhook.
    '''
    return call_az("az acr webhook show", locals())


def get_config(name, registry, resource_group=None):
    '''
    Get the service URI and custom headers for the webhook.
    '''
    return call_az("az acr webhook get-config", locals())


def list_events(name, registry, resource_group=None):
    '''
    List recent events for a webhook.
    '''
    return call_az("az acr webhook list-events", locals())


def ping(name, registry, resource_group=None):
    '''
    Trigger a ping event for a webhook.
    '''
    return call_az("az acr webhook ping", locals())


def update(name, registry, actions=None, add=None, force_string=None, headers=None, remove=None, resource_group=None, scope=None, set=None, status=None, tags=None, uri=None):
    '''
    Update a webhook.
    '''
    return call_az("az acr webhook update", locals())




from ..... pyaz_utils import call_az

def list(policy_name, resource_group):
    '''
    List properties of a web application firewall global configuration.
    '''
    return call_az("az network application-gateway waf-policy policy-setting list", locals())


def update(policy_name, resource_group, add=None, file_upload_limit_in_mb=None, force_string=None, max_request_body_size_in_kb=None, mode=None, remove=None, request_body_check=None, set=None, state=None):
    '''
    Update properties of a web application firewall global configuration.
    '''
    return call_az("az network application-gateway waf-policy policy-setting update", locals())




from ... pyaz_utils import call_az

def list():
    '''
    Get all reservation orders
    '''
    return call_az("az reservations reservation-order list", locals())


def show(reservation_order_id, expand=None):
    '''
    Get a specific reservation order.
    '''
    return call_az("az reservations reservation-order show", locals())


def calculate(applied_scope_type, billing_scope, display_name, quantity, reserved_resource_type, sku, term, applied_scope=None, billing_plan=None, instance_flexibility=None, location=None, renew=None):
    '''
    Calculate price for a reservation order.
    '''
    return call_az("az reservations reservation-order calculate", locals())


def purchase(applied_scope_type, billing_scope, display_name, quantity, reservation_order_id, reserved_resource_type, sku, term, applied_scope=None, billing_plan=None, instance_flexibility=None, location=None, renew=None):
    '''
    Purchase reservation order
    '''
    return call_az("az reservations reservation-order purchase", locals())




from .... pyaz_utils import call_az

def config(enable_cd, name, resource_group, slot=None):
    '''
    Configure continuous deployment via containers.
    '''
    return call_az("az functionapp deployment container config", locals())


def show_cd_url(name, resource_group, slot=None):
    '''
    Get the URL which can be used to configure webhooks for continuous deployment.
    '''
    return call_az("az functionapp deployment container show-cd-url", locals())




from .... pyaz_utils import call_az

def add(certificate_store, certificate_url, cluster_name, resource_group, source_vault_id):
    '''
    Add a secret to the node type.
    '''
    return call_az("az sf managed-node-type vm-secret add", locals())




from .... pyaz_utils import call_az
from . import address_pool, inbound_nat_rule


def create(name, nic_name, resource_group, app_gateway_address_pools=None, application_security_groups=None, gateway_name=None, lb_address_pools=None, lb_inbound_nat_rules=None, lb_name=None, make_primary=None, private_ip_address=None, private_ip_address_version=None, public_ip_address=None, subnet=None, vnet_name=None):
    '''
    Create an IP configuration.
    '''
    return call_az("az network nic ip-config create", locals())


def update(name, nic_name, resource_group, add=None, app_gateway_address_pools=None, application_security_groups=None, force_string=None, gateway_lb=None, gateway_name=None, lb_address_pools=None, lb_inbound_nat_rules=None, lb_name=None, make_primary=None, private_ip_address=None, private_ip_address_version=None, public_ip_address=None, remove=None, set=None, subnet=None, vnet_name=None):
    '''
    Update an IP configuration.
    '''
    return call_az("az network nic ip-config update", locals())


def list(nic_name, resource_group):
    '''
    List the IP configurations of a NIC.
    '''
    return call_az("az network nic ip-config list", locals())


def show(name, nic_name, resource_group):
    '''
    Show the details of an IP configuration.
    '''
    return call_az("az network nic ip-config show", locals())


def delete(name, nic_name, resource_group):
    '''
    Delete an IP configuration.
    '''
    return call_az("az network nic ip-config delete", locals())




from ... pyaz_utils import call_az

def create(name, description=None, display_name=None, management_group=None, metadata=None, mode=None, params=None, rules=None, subscription=None):
    '''
    Create a policy definition.
    '''
    return call_az("az policy definition create", locals())


def delete(name, management_group=None, subscription=None):
    '''
    Delete a policy definition.
    '''
    return call_az("az policy definition delete", locals())


def list(management_group=None, subscription=None):
    '''
    List policy definitions.
    '''
    return call_az("az policy definition list", locals())


def show(name, management_group=None, subscription=None):
    '''
    Show a policy definition.
    '''
    return call_az("az policy definition show", locals())


def update(name, description=None, display_name=None, management_group=None, metadata=None, mode=None, params=None, rules=None, subscription=None):
    '''
    Update a policy definition.
    '''
    return call_az("az policy definition update", locals())




from .. pyaz_utils import call_az

def install(target_platform=None, version=None):
    '''
    Install Bicep CLI.
    '''
    return call_az("az bicep install", locals())


def uninstall():
    '''
    Uninstall Bicep CLI.
    '''
    return call_az("az bicep uninstall", locals())


def upgrade(target_platform=None):
    '''
    Upgrade Bicep CLI to the latest version.
    '''
    return call_az("az bicep upgrade", locals())


def build(file, outdir=None, outfile=None, stdout=None):
    '''
    Build a Bicep file.
    '''
    return call_az("az bicep build", locals())


def decompile(file):
    '''
    Attempt to decompile an ARM template file to a Bicep file.
    '''
    return call_az("az bicep decompile", locals())


def publish(file, target):
    '''
    Publish a bicep file to a remote module registry.
    '''
    return call_az("az bicep publish", locals())


def version():
    '''
    Show the installed version of Bicep CLI.
    '''
    return call_az("az bicep version", locals())


def list_versions():
    '''
    List out all available versions of Bicep CLI.
    '''
    return call_az("az bicep list-versions", locals())




from ... pyaz_utils import call_az

def create(definition, assignment_id=None, resource_group=None):
    '''
    Creates a new registration assignment.
    '''
    return call_az("az managedservices assignment create", locals())


def show(assignment, include_definition=None, resource_group=None):
    '''
    Gets a registration assignment.
    '''
    return call_az("az managedservices assignment show", locals())


def delete(assignment, resource_group=None):
    '''
    Deletes the registration assignment.
    '''
    return call_az("az managedservices assignment delete", locals())


def list(include_definition=None, resource_group=None):
    '''
    List all the registration assignments.
    '''
    return call_az("az managedservices assignment list", locals())




from .... pyaz_utils import call_az

def show(account, database_name, schema_name, table_valued_function_name):
    return call_az("az dla catalog tvf show", locals())


def list(account, database_name, schema_name=None):
    '''
    List table valued functions in a database or schema.
    '''
    return call_az("az dla catalog tvf list", locals())




from ... pyaz_utils import call_az
from . import commitment_plan, deployment, identity, keys, network_rule


def create(kind, location, name, resource_group, sku, api_properties=None, assign_identity=None, custom_domain=None, encryption=None, storage=None, tags=None, yes=None):
    '''
    Manage Azure Cognitive Services accounts.
    '''
    return call_az("az cognitiveservices account create", locals())


def delete(name, resource_group):
    '''
    Manage Azure Cognitive Services accounts.
    '''
    return call_az("az cognitiveservices account delete", locals())


def show(name, resource_group):
    '''
    Manage Azure Cognitive Services accounts.
    '''
    return call_az("az cognitiveservices account show", locals())


def update(name, resource_group, api_properties=None, custom_domain=None, encryption=None, sku=None, storage=None, tags=None):
    '''
    Manage Azure Cognitive Services accounts.
    '''
    return call_az("az cognitiveservices account update", locals())


def list(resource_group=None):
    '''
    Manage Azure Cognitive Services accounts.
    '''
    return call_az("az cognitiveservices account list", locals())


def show_deleted(location, name, resource_group):
    '''
    Show a soft-deleted Azure Cognitive Services account.
    '''
    return call_az("az cognitiveservices account show-deleted", locals())


def list_deleted():
    '''
    List soft-deleted Azure Cognitive Services accounts.
    '''
    return call_az("az cognitiveservices account list-deleted", locals())


def purge(location, name, resource_group):
    '''
    Purge a soft-deleted Azure Cognitive Services account.
    '''
    return call_az("az cognitiveservices account purge", locals())


def recover(location, name, resource_group):
    '''
    Recover a soft-deleted Azure Cognitive Services account.
    '''
    return call_az("az cognitiveservices account recover", locals())


def list_skus(kind=None, location=None, name=None, resource_group=None):
    '''
    Manage Azure Cognitive Services accounts.
    '''
    return call_az("az cognitiveservices account list-skus", locals())


def list_usage(name, resource_group):
    return call_az("az cognitiveservices account list-usage", locals())


def list_kinds():
    return call_az("az cognitiveservices account list-kinds", locals())




from .... pyaz_utils import call_az

def show(database, location, name, server):
    '''
    Get a long term retention backup for a database.
    '''
    return call_az("az sql db ltr-backup show", locals())


def list(location, database=None, database_state=None, only_latest_per_database=None, resource_group=None, server=None):
    '''
    List the long term retention backups for a location, server or database.
    '''
    return call_az("az sql db ltr-backup list", locals())


def delete(database, location, name, server, yes=None):
    '''
    Delete a long term retention backup.
    '''
    return call_az("az sql db ltr-backup delete", locals())


def restore(backup_id, dest_database, dest_resource_group, dest_server, backup_storage_redundancy=None, no_wait=None):
    '''
    Restore a long term retention backup to a new database.
    '''
    return call_az("az sql db ltr-backup restore", locals())


def wait(name, resource_group, server, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the database is met.
    '''
    return call_az("az sql db ltr-backup wait", locals())




from .... pyaz_utils import call_az

def list(cluster_name, name, resource_group):
    '''
    List versions of a given managed application type.
    '''
    return call_az("az sf managed-application-type version list", locals())


def delete(cluster_name, name, resource_group, version):
    '''
    Delete a managed application type version.
    '''
    return call_az("az sf managed-application-type version delete", locals())


def show(cluster_name, name, resource_group, version):
    '''
    Show the properties of a managed application type version on an Azure Service Fabric managed cluster.
    '''
    return call_az("az sf managed-application-type version show", locals())


def create(cluster_name, name, package_url, resource_group, version, tags=None):
    '''
    Create a new managed application type on an Azure Service Fabric managed cluster.
    '''
    return call_az("az sf managed-application-type version create", locals())


def update(cluster_name, name, resource_group, version, package_url=None, tags=None):
    '''
    Update a managed application type version.
    '''
    return call_az("az sf managed-application-type version update", locals())




from .... pyaz_utils import call_az

def show(domain_name, name, resource_group):
    '''
    Get the details of a domain topic.
    '''
    return call_az("az eventgrid domain topic show", locals())


def list(domain_name, resource_group, odata_query=None):
    '''
    List available topics in a domain.
    '''
    return call_az("az eventgrid domain topic list", locals())


def delete(domain_name, name, resource_group):
    '''
    Delete a domain topic under a domain.
    '''
    return call_az("az eventgrid domain topic delete", locals())


def create(domain_name, name, resource_group):
    '''
    Create a domain topic under a domain.
    '''
    return call_az("az eventgrid domain topic create", locals())




from ... pyaz_utils import call_az

def show(billing_period_name=None, include_meter_details=None):
    '''
    Show the price sheet for an Azure subscription within a billing period.
    '''
    return call_az("az consumption pricesheet show", locals())




from ... pyaz_utils import call_az

def enable(disk_encryption_keyvault, name, resource_group, force=None, key_encryption_algorithm=None, key_encryption_key=None, key_encryption_keyvault=None, volume_type=None):
    '''
    Encrypt a VMSS with managed disks.
    '''
    return call_az("az vmss encryption enable", locals())


def disable(name, resource_group, force=None, volume_type=None):
    '''
    Disable the encryption on a VMSS with managed disks.
    '''
    return call_az("az vmss encryption disable", locals())


def show(name, resource_group):
    '''
    Show encryption status.
    '''
    return call_az("az vmss encryption show", locals())




from .... pyaz_utils import call_az

def show(name, profile_name, resource_group, type):
    '''
    Get the details of a traffic manager endpoint.
    '''
    return call_az("az network traffic-manager endpoint show", locals())


def delete(name, profile_name, resource_group, type):
    '''
    Delete a traffic manager endpoint.
    '''
    return call_az("az network traffic-manager endpoint delete", locals())


def create(name, profile_name, resource_group, type, custom_headers=None, endpoint_location=None, endpoint_monitor_status=None, endpoint_status=None, geo_mapping=None, min_child_endpoints=None, priority=None, subnets=None, target=None, target_resource_id=None, weight=None):
    '''
    Create a traffic manager endpoint.
    '''
    return call_az("az network traffic-manager endpoint create", locals())


def list(profile_name, resource_group, type=None):
    '''
    List traffic manager endpoints.
    '''
    return call_az("az network traffic-manager endpoint list", locals())


def update(name, profile_name, resource_group, add=None, custom_headers=None, endpoint_location=None, endpoint_monitor_status=None, endpoint_status=None, force_string=None, geo_mapping=None, min_child_endpoints=None, priority=None, remove=None, set=None, subnets=None, target=None, target_resource_id=None, type=None, weight=None):
    '''
    Update a traffic manager endpoint.
    '''
    return call_az("az network traffic-manager endpoint update", locals())


def show_geographic_hierarchy():
    '''
    Get the default geographic hierarchy used by the geographic traffic routing method.
    '''
    return call_az("az network traffic-manager endpoint show-geographic-hierarchy", locals())




from ... pyaz_utils import call_az

def show(db_name, key=None, name=None, resource_group_name=None, url_connection=None):
    '''
    Shows an Azure Cosmos DB database
    '''
    return call_az("az cosmosdb database show", locals())


def list(key=None, name=None, resource_group_name=None, url_connection=None):
    '''
    Lists all Azure Cosmos DB databases
    '''
    return call_az("az cosmosdb database list", locals())


def exists(db_name, key=None, name=None, resource_group_name=None, url_connection=None):
    '''
    Returns a boolean indicating whether the database exists
    '''
    return call_az("az cosmosdb database exists", locals())


def create(db_name, key=None, name=None, resource_group_name=None, throughput=None, url_connection=None):
    '''
    Creates an Azure Cosmos DB database
    '''
    return call_az("az cosmosdb database create", locals())


def delete(db_name, key=None, name=None, resource_group_name=None, url_connection=None, yes=None):
    '''
    Deletes an Azure Cosmos DB database
    '''
    return call_az("az cosmosdb database delete", locals())




from .... pyaz_utils import call_az

def reset(id, append=None, cert=None, create_cert=None, credential_description=None, end_date=None, keyvault=None, password=None, years=None):
    '''
    Append or overwrite an application's password or certificate credentials
    '''
    return call_az("az ad app credential reset", locals())


def list(id, cert=None):
    '''
    List an application's password or certificate credential metadata. (The content of the password or certificate credential is not retrievable.)
    '''
    return call_az("az ad app credential list", locals())


def delete(id, key_id, cert=None):
    '''
    delete an application's password or certificate credentials
    '''
    return call_az("az ad app credential delete", locals())

